package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.BatchConnectorMigrationTask;
import com.trendmicro.deepsecurity.model.BatchConnectorMigrationTaskList;
import com.trendmicro.deepsecurity.model.ConnectorMigrationTask;
import com.trendmicro.deepsecurity.model.ConnectorMigrationTasks;
import com.trendmicro.deepsecurity.model.SearchFilter;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class AwsConnectorMigrationTasksApi {
  private ApiClient apiClient;

  public AwsConnectorMigrationTasksApi() {
    this(Configuration.getDefaultApiClient());
  }

  public AwsConnectorMigrationTasksApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Create a Connector Migration Task
   * Create a new AWS Connector Migration Task.
   * @param connectorMigrationTask The task to migrate the connector. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return ConnectorMigrationTask
   * @throws ApiException if fails to make API call
   */
  public ConnectorMigrationTask createConnectorMigrationTask(ConnectorMigrationTask connectorMigrationTask, String apiVersion) throws ApiException {
    Object localVarPostBody = connectorMigrationTask;
    
    // verify the required parameter 'connectorMigrationTask' is set
    if (connectorMigrationTask == null) {
      throw new ApiException(400, "Missing the required parameter 'connectorMigrationTask' when calling createConnectorMigrationTask");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling createConnectorMigrationTask");
    }
    
    // create path and map variables
    String localVarPath = "/connectormigrationtasks/aws".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ConnectorMigrationTask> localVarReturnType = new GenericType<ConnectorMigrationTask>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Create Connector Migration Tasks
   * Create new AWS Connector Migration Tasks.
   * @param connectorIDs The task to migrate the connector. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return BatchConnectorMigrationTaskList
   * @throws ApiException if fails to make API call
   */
  public BatchConnectorMigrationTaskList createConnectorMigrationTasks(BatchConnectorMigrationTask connectorIDs, String apiVersion) throws ApiException {
    Object localVarPostBody = connectorIDs;
    
    // verify the required parameter 'connectorIDs' is set
    if (connectorIDs == null) {
      throw new ApiException(400, "Missing the required parameter 'connectorIDs' when calling createConnectorMigrationTasks");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling createConnectorMigrationTasks");
    }
    
    // create path and map variables
    String localVarPath = "/batchconnectormigrationtasks/aws".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<BatchConnectorMigrationTaskList> localVarReturnType = new GenericType<BatchConnectorMigrationTaskList>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Describe a Connector Migration Task
   * Describe an AWS connector migration task.
   * @param connectorMigrationTaskID The ID number of the connector migration task to describe. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return ConnectorMigrationTask
   * @throws ApiException if fails to make API call
   */
  public ConnectorMigrationTask describeConnectorMigrationTask(Long connectorMigrationTaskID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'connectorMigrationTaskID' is set
    if (connectorMigrationTaskID == null) {
      throw new ApiException(400, "Missing the required parameter 'connectorMigrationTaskID' when calling describeConnectorMigrationTask");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeConnectorMigrationTask");
    }
    
    // create path and map variables
    String localVarPath = "/connectormigrationtasks/aws/{connectorMigrationTaskID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "connectorMigrationTaskID" + "\\}", apiClient.escapeString(connectorMigrationTaskID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ConnectorMigrationTask> localVarReturnType = new GenericType<ConnectorMigrationTask>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Connector Migration Tasks
   * Describe AWS connector migration tasks.
   * @param apiVersion The version of the api being called. (required)
   * @return ConnectorMigrationTasks
   * @throws ApiException if fails to make API call
   */
  public ConnectorMigrationTasks listConnectorMigrationTasks(String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listConnectorMigrationTasks");
    }
    
    // create path and map variables
    String localVarPath = "/connectormigrationtasks/aws".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ConnectorMigrationTasks> localVarReturnType = new GenericType<ConnectorMigrationTasks>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Search Connector Migration Tasks
   * Search for AWS connector migration task using optional filters.
   * @param searchFilter A collection of options used to filter the search results. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return ConnectorMigrationTasks
   * @throws ApiException if fails to make API call
   */
  public ConnectorMigrationTasks searchConnectorMigrationTasks(SearchFilter searchFilter, String apiVersion) throws ApiException {
    Object localVarPostBody = searchFilter;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling searchConnectorMigrationTasks");
    }
    
    // create path and map variables
    String localVarPath = "/connectormigrationtasks/aws/search".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ConnectorMigrationTasks> localVarReturnType = new GenericType<ConnectorMigrationTasks>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
