package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.AWSConnector;
import com.trendmicro.deepsecurity.model.AWSConnectors;
import com.trendmicro.deepsecurity.model.SearchFilter;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class AwsConnectorsApi {
  private ApiClient apiClient;

  public AwsConnectorsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public AwsConnectorsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Create an AWS Connector
   * Create a new AWS Connector.
   * @param awsConnector The settings of the new AWS Connector. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return AWSConnector
   * @throws ApiException if fails to make API call
   */
  public AWSConnector createAWSConnector(AWSConnector awsConnector, String apiVersion) throws ApiException {
    Object localVarPostBody = awsConnector;
    
    // verify the required parameter 'awsConnector' is set
    if (awsConnector == null) {
      throw new ApiException(400, "Missing the required parameter 'awsConnector' when calling createAWSConnector");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling createAWSConnector");
    }
    
    // create path and map variables
    String localVarPath = "/awsconnectors".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<AWSConnector> localVarReturnType = new GenericType<AWSConnector>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Delete an AWS Connector
   * Delete an existing AWS Connector by ID.
   * @param awsConnectorID The ID number of the AWS Connector to delete. (required)
   * @param apiVersion The version of the api being called. (required)
   * @throws ApiException if fails to make API call
   */
  public void deleteAWSConnector(Integer awsConnectorID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'awsConnectorID' is set
    if (awsConnectorID == null) {
      throw new ApiException(400, "Missing the required parameter 'awsConnectorID' when calling deleteAWSConnector");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling deleteAWSConnector");
    }
    
    // create path and map variables
    String localVarPath = "/awsconnectors/{awsConnectorID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "awsConnectorID" + "\\}", apiClient.escapeString(awsConnectorID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };


    apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, null);
  }
  /**
   * Describe an existing AWS Connector
   * Describe an AWS Connector by ID.
   * @param awsConnectorID The ID number of the AWS Connector to describe. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return AWSConnector
   * @throws ApiException if fails to make API call
   */
  public AWSConnector describeAWSConnector(Integer awsConnectorID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'awsConnectorID' is set
    if (awsConnectorID == null) {
      throw new ApiException(400, "Missing the required parameter 'awsConnectorID' when calling describeAWSConnector");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeAWSConnector");
    }
    
    // create path and map variables
    String localVarPath = "/awsconnectors/{awsConnectorID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "awsConnectorID" + "\\}", apiClient.escapeString(awsConnectorID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<AWSConnector> localVarReturnType = new GenericType<AWSConnector>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List AWS Connectors
   * Lists all AWS Connectors.
   * @param apiVersion The version of the api being called. (required)
   * @return AWSConnectors
   * @throws ApiException if fails to make API call
   */
  public AWSConnectors listAWSConnectors(String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listAWSConnectors");
    }
    
    // create path and map variables
    String localVarPath = "/awsconnectors".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<AWSConnectors> localVarReturnType = new GenericType<AWSConnectors>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify an AWS Connector
   * Modify the specified AWS Connector by ID. Any unset elements will be left unchanged.
   * @param awsConnectorID The ID number of the AWS Connector to modify. (required)
   * @param sync Immediately trigger a synchronization for the AWS Connector. (optional)
   * @param awsConnector The settings of the AWS Connector to modify. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return AWSConnector
   * @throws ApiException if fails to make API call
   */
  public AWSConnector modifyAWSConnector(Integer awsConnectorID, Boolean sync, AWSConnector awsConnector, String apiVersion) throws ApiException {
    Object localVarPostBody = awsConnector;
    
    // verify the required parameter 'awsConnectorID' is set
    if (awsConnectorID == null) {
      throw new ApiException(400, "Missing the required parameter 'awsConnectorID' when calling modifyAWSConnector");
    }
    
    // verify the required parameter 'awsConnector' is set
    if (awsConnector == null) {
      throw new ApiException(400, "Missing the required parameter 'awsConnector' when calling modifyAWSConnector");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyAWSConnector");
    }
    
    // create path and map variables
    String localVarPath = "/awsconnectors/{awsConnectorID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "awsConnectorID" + "\\}", apiClient.escapeString(awsConnectorID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "sync", sync));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<AWSConnector> localVarReturnType = new GenericType<AWSConnector>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Search AWS Connectors
   * Search for AWS Connectors using optional filters.
   * @param searchFilter A collection of options used to filter the search results. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return AWSConnectors
   * @throws ApiException if fails to make API call
   */
  public AWSConnectors searchAWSConnectors(SearchFilter searchFilter, String apiVersion) throws ApiException {
    Object localVarPostBody = searchFilter;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling searchAWSConnectors");
    }
    
    // create path and map variables
    String localVarPath = "/awsconnectors/search".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<AWSConnectors> localVarReturnType = new GenericType<AWSConnectors>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
