package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.AzureConnector;
import com.trendmicro.deepsecurity.model.AzureConnectors;
import com.trendmicro.deepsecurity.model.SearchFilter;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class AzureConnectorsApi {
  private ApiClient apiClient;

  public AzureConnectorsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public AzureConnectorsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Create an Azure Connector
   * Create a new Azure Connector.
   * @param azureConnector The settings of the new Azure Connector. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return AzureConnector
   * @throws ApiException if fails to make API call
   */
  public AzureConnector createAzureConnector(AzureConnector azureConnector, String apiVersion) throws ApiException {
    Object localVarPostBody = azureConnector;
    
    // verify the required parameter 'azureConnector' is set
    if (azureConnector == null) {
      throw new ApiException(400, "Missing the required parameter 'azureConnector' when calling createAzureConnector");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling createAzureConnector");
    }
    
    // create path and map variables
    String localVarPath = "/azureconnectors".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<AzureConnector> localVarReturnType = new GenericType<AzureConnector>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Delete an Azure Connector
   * Delete an existing Azure Connector by ID.
   * @param azureConnectorID The ID number of the Azure Connector to delete. (required)
   * @param apiVersion The version of the api being called. (required)
   * @throws ApiException if fails to make API call
   */
  public void deleteAzureConnector(Integer azureConnectorID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'azureConnectorID' is set
    if (azureConnectorID == null) {
      throw new ApiException(400, "Missing the required parameter 'azureConnectorID' when calling deleteAzureConnector");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling deleteAzureConnector");
    }
    
    // create path and map variables
    String localVarPath = "/azureconnectors/{azureConnectorID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "azureConnectorID" + "\\}", apiClient.escapeString(azureConnectorID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };


    apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, null);
  }
  /**
   * Describe an existing Azure Connector
   * Describe an Azure Connector by ID.
   * @param azureConnectorID The ID number of the Azure Connector to describe. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return AzureConnector
   * @throws ApiException if fails to make API call
   */
  public AzureConnector describeAzureConnector(Integer azureConnectorID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'azureConnectorID' is set
    if (azureConnectorID == null) {
      throw new ApiException(400, "Missing the required parameter 'azureConnectorID' when calling describeAzureConnector");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeAzureConnector");
    }
    
    // create path and map variables
    String localVarPath = "/azureconnectors/{azureConnectorID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "azureConnectorID" + "\\}", apiClient.escapeString(azureConnectorID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<AzureConnector> localVarReturnType = new GenericType<AzureConnector>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Azure Connectors
   * Lists all Azure Connectors.
   * @param apiVersion The version of the api being called. (required)
   * @return AzureConnectors
   * @throws ApiException if fails to make API call
   */
  public AzureConnectors listAzureConnectors(String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listAzureConnectors");
    }
    
    // create path and map variables
    String localVarPath = "/azureconnectors".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<AzureConnectors> localVarReturnType = new GenericType<AzureConnectors>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify an Azure Connector
   * Modify the specified Azure Connector by ID. Any unset elements will be left unchanged. Property &#x60;azureTenantID&#x60;, &#x60;subscriptionID&#x60;, &#x60;loginApiEndPoint&#x60; and &#x60;resourceApiEndPoint&#x60; can&#39;t be modified.
   * @param azureConnectorID The ID number of the Azure Connector to modify. (required)
   * @param sync Immediately trigger a synchronization for the Azure Connector. (optional)
   * @param azureConnector The settings of the Azure Connector to modify. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return AzureConnector
   * @throws ApiException if fails to make API call
   */
  public AzureConnector modifyAzureConnector(Integer azureConnectorID, Boolean sync, AzureConnector azureConnector, String apiVersion) throws ApiException {
    Object localVarPostBody = azureConnector;
    
    // verify the required parameter 'azureConnectorID' is set
    if (azureConnectorID == null) {
      throw new ApiException(400, "Missing the required parameter 'azureConnectorID' when calling modifyAzureConnector");
    }
    
    // verify the required parameter 'azureConnector' is set
    if (azureConnector == null) {
      throw new ApiException(400, "Missing the required parameter 'azureConnector' when calling modifyAzureConnector");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyAzureConnector");
    }
    
    // create path and map variables
    String localVarPath = "/azureconnectors/{azureConnectorID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "azureConnectorID" + "\\}", apiClient.escapeString(azureConnectorID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "sync", sync));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<AzureConnector> localVarReturnType = new GenericType<AzureConnector>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Search Azure Connectors
   * Search for Azure Connectors using optional filters.
   * @param searchFilter A collection of options used to filter the search results. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return AzureConnectors
   * @throws ApiException if fails to make API call
   */
  public AzureConnectors searchAzureConnectors(SearchFilter searchFilter, String apiVersion) throws ApiException {
    Object localVarPostBody = searchFilter;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling searchAzureConnectors");
    }
    
    // create path and map variables
    String localVarPath = "/azureconnectors/search".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<AzureConnectors> localVarReturnType = new GenericType<AzureConnectors>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
