package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.ExceptionRules;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class ComputerDeviceControlExceptionRulesApi {
  private ApiClient apiClient;

  public ComputerDeviceControlExceptionRulesApi() {
    this(Configuration.getDefaultApiClient());
  }

  public ComputerDeviceControlExceptionRulesApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Add Device Exception Rules
   * Assign device exception rules to a computer.
   * @param computerID The ID number of the computer. (required)
   * @param exceptionRules Exception Rules for the device. (required)
   * @param overrides Return only Exception Rules directly related to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return ExceptionRules
   * @throws ApiException if fails to make API call
   */
  public ExceptionRules addExceptionRulesOnComputer(Integer computerID, ExceptionRules exceptionRules, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = exceptionRules;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling addExceptionRulesOnComputer");
    }
    
    // verify the required parameter 'exceptionRules' is set
    if (exceptionRules == null) {
      throw new ApiException(400, "Missing the required parameter 'exceptionRules' when calling addExceptionRulesOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling addExceptionRulesOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/devicecontrol/usbdeviceexceptionrules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ExceptionRules> localVarReturnType = new GenericType<ExceptionRules>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Device Exception Rules
   * Lists all device exception rules assigned to a computer.
   * @param computerID The ID number of the computer. (required)
   * @param overrides Return only Exception Rules directly related to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return ExceptionRules
   * @throws ApiException if fails to make API call
   */
  public ExceptionRules listExceptionRulesOnComputer(Integer computerID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling listExceptionRulesOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listExceptionRulesOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/devicecontrol/usbdeviceexceptionrules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ExceptionRules> localVarReturnType = new GenericType<ExceptionRules>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Remove a Device Exception Rule
   * Unassign a device exception rule from a computer.
   * @param computerID The ID number of the computer. (required)
   * @param exceptionRuleID The ID number of the Exception Rule to delete. (required)
   * @param overrides Return only Exception Rules directly related to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return ExceptionRules
   * @throws ApiException if fails to make API call
   */
  public ExceptionRules removeExceptionRuleOnComputer(Integer computerID, Long exceptionRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling removeExceptionRuleOnComputer");
    }
    
    // verify the required parameter 'exceptionRuleID' is set
    if (exceptionRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'exceptionRuleID' when calling removeExceptionRuleOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling removeExceptionRuleOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/devicecontrol/usbdeviceexceptionrules/{exceptionRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()))
      .replaceAll("\\{" + "exceptionRuleID" + "\\}", apiClient.escapeString(exceptionRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ExceptionRules> localVarReturnType = new GenericType<ExceptionRules>() {};
    return apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Set Device Exception Rules
   * Set device exception rules assigned to a computer.
   * @param computerID The ID number of the computer. (required)
   * @param exceptionRules Exception Rules for the device. (required)
   * @param overrides Return only Exception Rules directly related to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return ExceptionRules
   * @throws ApiException if fails to make API call
   */
  public ExceptionRules setExceptionRulesOnComputer(Integer computerID, ExceptionRules exceptionRules, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = exceptionRules;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling setExceptionRulesOnComputer");
    }
    
    // verify the required parameter 'exceptionRules' is set
    if (exceptionRules == null) {
      throw new ApiException(400, "Missing the required parameter 'exceptionRules' when calling setExceptionRulesOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling setExceptionRulesOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/devicecontrol/usbdeviceexceptionrules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ExceptionRules> localVarReturnType = new GenericType<ExceptionRules>() {};
    return apiClient.invokeAPI(localVarPath, "PUT", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
