package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.FirewallAssignments;
import com.trendmicro.deepsecurity.model.RuleIDs;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class ComputerFirewallRuleAssignmentsApi {
  private ApiClient apiClient;

  public ComputerFirewallRuleAssignmentsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public ComputerFirewallRuleAssignmentsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Add Firewall Rule IDs
   * Assign firewall rule IDs to a computer.
   * @param computerID The ID number of the computer. (required)
   * @param firewallRuleIDs The ID numbers of the firewall rules to add. (required)
   * @param overrides Return only rule IDs assigned directly to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return FirewallAssignments
   * @throws ApiException if fails to make API call
   */
  public FirewallAssignments addFirewallRuleIDsToComputer(Integer computerID, RuleIDs firewallRuleIDs, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = firewallRuleIDs;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling addFirewallRuleIDsToComputer");
    }
    
    // verify the required parameter 'firewallRuleIDs' is set
    if (firewallRuleIDs == null) {
      throw new ApiException(400, "Missing the required parameter 'firewallRuleIDs' when calling addFirewallRuleIDsToComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling addFirewallRuleIDsToComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/firewall/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FirewallAssignments> localVarReturnType = new GenericType<FirewallAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Firewall Rule IDs
   * Lists all firewall rule IDs assigned to a computer.
   * @param computerID The ID number of the computer. (required)
   * @param overrides Return only rule IDs assigned directly to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return FirewallAssignments
   * @throws ApiException if fails to make API call
   */
  public FirewallAssignments listFirewallRuleIDsOnComputer(Integer computerID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling listFirewallRuleIDsOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listFirewallRuleIDsOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/firewall/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FirewallAssignments> localVarReturnType = new GenericType<FirewallAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Remove a Firewall Rule ID
   * Unassign a firewall rule ID from a computer.
   * @param computerID The ID number of the computer. (required)
   * @param firewallRuleID The ID number of the firewall rule to delete. (required)
   * @param overrides Return only rule IDs assigned directly to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return FirewallAssignments
   * @throws ApiException if fails to make API call
   */
  public FirewallAssignments removeFirewallRuleIDFromComputer(Integer computerID, Integer firewallRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling removeFirewallRuleIDFromComputer");
    }
    
    // verify the required parameter 'firewallRuleID' is set
    if (firewallRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'firewallRuleID' when calling removeFirewallRuleIDFromComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling removeFirewallRuleIDFromComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/firewall/assignments/{firewallRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()))
      .replaceAll("\\{" + "firewallRuleID" + "\\}", apiClient.escapeString(firewallRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FirewallAssignments> localVarReturnType = new GenericType<FirewallAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Set Firewall Rule IDs
   * Set firewall rule IDs assigned to a computer.
   * @param computerID The ID number of the computer. (required)
   * @param firewallRuleIDs The ID numbers of the firewall rules to set. (optional)
   * @param overrides Return only rule IDs assigned directly to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return FirewallAssignments
   * @throws ApiException if fails to make API call
   */
  public FirewallAssignments setFirewallRuleIDsOnComputer(Integer computerID, RuleIDs firewallRuleIDs, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = firewallRuleIDs;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling setFirewallRuleIDsOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling setFirewallRuleIDsOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/firewall/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FirewallAssignments> localVarReturnType = new GenericType<FirewallAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "PUT", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
