package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.IntrusionPreventionAssignments;
import com.trendmicro.deepsecurity.model.RuleIDs;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class ComputerIntrusionPreventionRuleAssignmentsRecommendationsApi {
  private ApiClient apiClient;

  public ComputerIntrusionPreventionRuleAssignmentsRecommendationsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public ComputerIntrusionPreventionRuleAssignmentsRecommendationsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Add Intrusion Prevention Rule IDs
   * Assign intrusion prevention rule IDs to a computer.
   * @param computerID The ID number of the computer. (required)
   * @param intrusionPreventionRuleIDs The ID numbers of the intrusion prevention rules to add. (optional)
   * @param overrides Return only rule IDs assigned directly to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntrusionPreventionAssignments
   * @throws ApiException if fails to make API call
   */
  public IntrusionPreventionAssignments addIntrusionPreventionRuleIDsToComputer(Integer computerID, RuleIDs intrusionPreventionRuleIDs, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = intrusionPreventionRuleIDs;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling addIntrusionPreventionRuleIDsToComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling addIntrusionPreventionRuleIDsToComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/intrusionprevention/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntrusionPreventionAssignments> localVarReturnType = new GenericType<IntrusionPreventionAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Intrusion Prevention Rule IDs
   * Lists all intrusion prevention rule IDs assigned to a computer.
   * @param computerID The ID number of the computer. (required)
   * @param overrides Return only rule IDs assigned directly to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntrusionPreventionAssignments
   * @throws ApiException if fails to make API call
   */
  public IntrusionPreventionAssignments listIntrusionPreventionRuleIDsOnComputer(Integer computerID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling listIntrusionPreventionRuleIDsOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listIntrusionPreventionRuleIDsOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/intrusionprevention/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntrusionPreventionAssignments> localVarReturnType = new GenericType<IntrusionPreventionAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Remove an Intrusion Prevention Rule ID
   * Unassign an intrusion prevention rule ID from a computer.
   * @param computerID The ID number of the computer. (required)
   * @param intrusionPreventionRuleID The ID number of the intrusion prevention rule to delete. (required)
   * @param overrides Return only rule IDs assigned directly to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntrusionPreventionAssignments
   * @throws ApiException if fails to make API call
   */
  public IntrusionPreventionAssignments removeIntrusionPreventionRuleIDFromComputer(Integer computerID, Integer intrusionPreventionRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling removeIntrusionPreventionRuleIDFromComputer");
    }
    
    // verify the required parameter 'intrusionPreventionRuleID' is set
    if (intrusionPreventionRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'intrusionPreventionRuleID' when calling removeIntrusionPreventionRuleIDFromComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling removeIntrusionPreventionRuleIDFromComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/intrusionprevention/assignments/{intrusionPreventionRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()))
      .replaceAll("\\{" + "intrusionPreventionRuleID" + "\\}", apiClient.escapeString(intrusionPreventionRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntrusionPreventionAssignments> localVarReturnType = new GenericType<IntrusionPreventionAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Set Intrusion Prevention Rule IDs
   * Set intrusion prevention rule IDs assigned to a computer.
   * @param computerID The ID number of the computer. (required)
   * @param intrusionPreventionRuleIDs The ID numbers of the intrusion prevention rules to set. (optional)
   * @param overrides Return only rule IDs assigned directly to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntrusionPreventionAssignments
   * @throws ApiException if fails to make API call
   */
  public IntrusionPreventionAssignments setIntrusionPreventionRuleIDsOnComputer(Integer computerID, RuleIDs intrusionPreventionRuleIDs, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = intrusionPreventionRuleIDs;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling setIntrusionPreventionRuleIDsOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling setIntrusionPreventionRuleIDsOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/intrusionprevention/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntrusionPreventionAssignments> localVarReturnType = new GenericType<IntrusionPreventionAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "PUT", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
