package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.IntrusionPreventionRule;
import com.trendmicro.deepsecurity.model.IntrusionPreventionRules;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class ComputerIntrusionPreventionRuleDetailsApi {
  private ApiClient apiClient;

  public ComputerIntrusionPreventionRuleDetailsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public ComputerIntrusionPreventionRuleDetailsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Describe an intrusion prevention rule
   * Describe an intrusion prevention rule including computer-level overrides.
   * @param computerID The ID number of the computer. (required)
   * @param intrusionPreventionRuleID The ID number of the intrusion prevention rule. (required)
   * @param overrides Show only overrides defined for the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntrusionPreventionRule
   * @throws ApiException if fails to make API call
   */
  public IntrusionPreventionRule describeIntrusionPreventionRuleOnComputer(Integer computerID, Integer intrusionPreventionRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling describeIntrusionPreventionRuleOnComputer");
    }
    
    // verify the required parameter 'intrusionPreventionRuleID' is set
    if (intrusionPreventionRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'intrusionPreventionRuleID' when calling describeIntrusionPreventionRuleOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeIntrusionPreventionRuleOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/intrusionprevention/rules/{intrusionPreventionRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()))
      .replaceAll("\\{" + "intrusionPreventionRuleID" + "\\}", apiClient.escapeString(intrusionPreventionRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntrusionPreventionRule> localVarReturnType = new GenericType<IntrusionPreventionRule>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List intrusion prevention rules
   * Lists all intrusion prevention rules assigned to a computer.
   * @param computerID The ID number of the computer. (required)
   * @param overrides Show only rules assigned to the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntrusionPreventionRules
   * @throws ApiException if fails to make API call
   */
  public IntrusionPreventionRules listIntrusionPreventionRulesOnComputer(Integer computerID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling listIntrusionPreventionRulesOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listIntrusionPreventionRulesOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/intrusionprevention/rules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntrusionPreventionRules> localVarReturnType = new GenericType<IntrusionPreventionRules>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify an intrusion prevention rule
   * Modify an intrusion prevention rule assigned to a computer. Any unset elements will be left unchanged.
   * @param computerID The ID number of the computer. (required)
   * @param intrusionPreventionRuleID The ID number of the intrusion prevention rule to modify. (required)
   * @param intrusionPreventionRule The settings of the intrusion prevention rule to modify. (required)
   * @param overrides Show only overrides defined for the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntrusionPreventionRule
   * @throws ApiException if fails to make API call
   */
  public IntrusionPreventionRule modifyIntrusionPreventionRuleOnComputer(Integer computerID, Integer intrusionPreventionRuleID, IntrusionPreventionRule intrusionPreventionRule, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = intrusionPreventionRule;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling modifyIntrusionPreventionRuleOnComputer");
    }
    
    // verify the required parameter 'intrusionPreventionRuleID' is set
    if (intrusionPreventionRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'intrusionPreventionRuleID' when calling modifyIntrusionPreventionRuleOnComputer");
    }
    
    // verify the required parameter 'intrusionPreventionRule' is set
    if (intrusionPreventionRule == null) {
      throw new ApiException(400, "Missing the required parameter 'intrusionPreventionRule' when calling modifyIntrusionPreventionRuleOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyIntrusionPreventionRuleOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/intrusionprevention/rules/{intrusionPreventionRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()))
      .replaceAll("\\{" + "intrusionPreventionRuleID" + "\\}", apiClient.escapeString(intrusionPreventionRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntrusionPreventionRule> localVarReturnType = new GenericType<IntrusionPreventionRule>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Reset intrusion prevention rule overrides
   * Remove all overrides for an intrusion prevention rule from a computer.
   * @param computerID The ID number of the computer. (required)
   * @param intrusionPreventionRuleID The ID number of the intrusion prevention rule to reset. (required)
   * @param overrides Show only overrides defined for the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntrusionPreventionRule
   * @throws ApiException if fails to make API call
   */
  public IntrusionPreventionRule resetIntrusionPreventionRuleOnComputer(Integer computerID, Integer intrusionPreventionRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling resetIntrusionPreventionRuleOnComputer");
    }
    
    // verify the required parameter 'intrusionPreventionRuleID' is set
    if (intrusionPreventionRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'intrusionPreventionRuleID' when calling resetIntrusionPreventionRuleOnComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling resetIntrusionPreventionRuleOnComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/intrusionprevention/rules/{intrusionPreventionRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()))
      .replaceAll("\\{" + "intrusionPreventionRuleID" + "\\}", apiClient.escapeString(intrusionPreventionRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntrusionPreventionRule> localVarReturnType = new GenericType<IntrusionPreventionRule>() {};
    return apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
