package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.Computer;
import com.trendmicro.deepsecurity.model.Computers;
import com.trendmicro.deepsecurity.model.SearchFilter;
import com.trendmicro.deepsecurity.model.SettingValue;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class ComputersApi {
  private ApiClient apiClient;

  public ComputersApi() {
    this(Configuration.getDefaultApiClient());
  }

  public ComputersApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Create a Computer
   * Create a new computer.
   * @param computer The settings of the new computer. (required)
   * @param expand Determines the computer information to include in the response. Use \&quot;none\&quot; to retrieve only basic computer information such as policyID and hostName. Use one or several expand options to retrieve a tailored response in addition to the basic information. Use \&quot;all\&quot; to retrieve all of the computer information. The default is \&quot;all\&quot;, but we recommend using \&quot;none\&quot; or a limited set of options on all requests to improve performance. (optional)
   * @param overrides Show only overrides defined for the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return Computer
   * @throws ApiException if fails to make API call
   */
  public Computer createComputer(Computer computer, List<String> expand, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = computer;
    
    // verify the required parameter 'computer' is set
    if (computer == null) {
      throw new ApiException(400, "Missing the required parameter 'computer' when calling createComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling createComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("multi", "expand", expand));
    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Computer> localVarReturnType = new GenericType<Computer>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Delete a Computer
   * Delete a computer by ID. You cannot use this operation to delete a computer that is managed by a connector.
   * @param computerID The ID number of the computer to delete. (required)
   * @param apiVersion The version of the api being called. (required)
   * @throws ApiException if fails to make API call
   */
  public void deleteComputer(Integer computerID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling deleteComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling deleteComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };


    apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, null);
  }
  /**
   * Describe a Computer
   * Describe a computer by ID.
   * @param computerID The ID number of the computer to describe. (required)
   * @param expand Determines the computer information to include in the response. Use \&quot;none\&quot; to retrieve only basic computer information such as policyID and hostName. Use one or several expand options to retrieve a tailored response in addition to the basic information. Use \&quot;all\&quot; to retrieve all of the computer information. The default is \&quot;all\&quot;, but we recommend using \&quot;none\&quot; or a limited set of options on all requests to improve performance. (optional)
   * @param overrides Show only overrides defined for the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return Computer
   * @throws ApiException if fails to make API call
   */
  public Computer describeComputer(Integer computerID, List<String> expand, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling describeComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("multi", "expand", expand));
    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Computer> localVarReturnType = new GenericType<Computer>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Describe a Computer Setting
   * Return the value for a computer setting.
   * @param computerID The ID number of the computer. (required)
   * @param name The name of the setting. (required)
   * @param overrides Show the value only if defined for the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return SettingValue
   * @throws ApiException if fails to make API call
   */
  public SettingValue describeComputerSetting(Integer computerID, String name, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling describeComputerSetting");
    }
    
    // verify the required parameter 'name' is set
    if (name == null) {
      throw new ApiException(400, "Missing the required parameter 'name' when calling describeComputerSetting");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeComputerSetting");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/settings/{name}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()))
      .replaceAll("\\{" + "name" + "\\}", apiClient.escapeString(name.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<SettingValue> localVarReturnType = new GenericType<SettingValue>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Computers
   * Lists all computers.
   * @param expand Determines the computer information to include in the response. Use \&quot;none\&quot; to retrieve only basic computer information such as policyID and hostName. Use one or several expand options to retrieve a tailored response in addition to the basic information. Use \&quot;all\&quot; to retrieve all of the computer information. The default is \&quot;all\&quot;, but we recommend using \&quot;none\&quot; or a limited set of options on all requests to improve performance. (optional)
   * @param overrides Show only overrides defined for the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return Computers
   * @throws ApiException if fails to make API call
   */
  public Computers listComputers(List<String> expand, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listComputers");
    }
    
    // create path and map variables
    String localVarPath = "/computers".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("multi", "expand", expand));
    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Computers> localVarReturnType = new GenericType<Computers>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify a Computer
   * Modify a computer by ID. Any unset elements will be left unchanged.
   * @param computerID The ID number of the computer to modify. (required)
   * @param computer The settings of the computer to modify. (required)
   * @param expand Determines the computer information to include in the response. Use \&quot;none\&quot; to retrieve only basic computer information such as policyID and hostName. Use one or several expand options to retrieve a tailored response in addition to the basic information. Use \&quot;all\&quot; to retrieve all of the computer information. The default is \&quot;all\&quot;, but we recommend using \&quot;none\&quot; or a limited set of options on all requests to improve performance. (optional)
   * @param overrides Show only overrides defined for the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return Computer
   * @throws ApiException if fails to make API call
   */
  public Computer modifyComputer(Integer computerID, Computer computer, List<String> expand, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = computer;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling modifyComputer");
    }
    
    // verify the required parameter 'computer' is set
    if (computer == null) {
      throw new ApiException(400, "Missing the required parameter 'computer' when calling modifyComputer");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyComputer");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("multi", "expand", expand));
    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Computer> localVarReturnType = new GenericType<Computer>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify a Computer Setting
   * Modify the value for a computer setting.
   * @param computerID The ID number of the policy. (required)
   * @param name The name of the setting. (required)
   * @param value The new value for the setting. (required)
   * @param overrides Show the value only if defined for the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return SettingValue
   * @throws ApiException if fails to make API call
   */
  public SettingValue modifyComputerSetting(Integer computerID, String name, SettingValue value, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = value;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling modifyComputerSetting");
    }
    
    // verify the required parameter 'name' is set
    if (name == null) {
      throw new ApiException(400, "Missing the required parameter 'name' when calling modifyComputerSetting");
    }
    
    // verify the required parameter 'value' is set
    if (value == null) {
      throw new ApiException(400, "Missing the required parameter 'value' when calling modifyComputerSetting");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyComputerSetting");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/settings/{name}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()))
      .replaceAll("\\{" + "name" + "\\}", apiClient.escapeString(name.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<SettingValue> localVarReturnType = new GenericType<SettingValue>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Reset a Computer Setting
   * Reset the value for a computer setting.
   * @param computerID The ID number of the policy. (required)
   * @param name The name of the setting. (required)
   * @param overrides Show the value only if defined for the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return SettingValue
   * @throws ApiException if fails to make API call
   */
  public SettingValue resetComputerSetting(Integer computerID, String name, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'computerID' is set
    if (computerID == null) {
      throw new ApiException(400, "Missing the required parameter 'computerID' when calling resetComputerSetting");
    }
    
    // verify the required parameter 'name' is set
    if (name == null) {
      throw new ApiException(400, "Missing the required parameter 'name' when calling resetComputerSetting");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling resetComputerSetting");
    }
    
    // create path and map variables
    String localVarPath = "/computers/{computerID}/settings/{name}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "computerID" + "\\}", apiClient.escapeString(computerID.toString()))
      .replaceAll("\\{" + "name" + "\\}", apiClient.escapeString(name.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<SettingValue> localVarReturnType = new GenericType<SettingValue>() {};
    return apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Search Computers
   * Search for computers using optional filters.
   * @param searchFilter A collection of options used to filter the search results. (optional)
   * @param expand Determines the computer information to include in the response. Use \&quot;none\&quot; to retrieve only basic computer information such as policyID and hostName. Use one or several expand options to retrieve a tailored response in addition to the basic information. Use \&quot;all\&quot; to retrieve all of the computer information. The default is \&quot;all\&quot;, but we recommend using \&quot;none\&quot; or a limited set of options on all requests to improve performance. (optional)
   * @param overrides Show only overrides defined for the current computer. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return Computers
   * @throws ApiException if fails to make API call
   */
  public Computers searchComputers(SearchFilter searchFilter, List<String> expand, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = searchFilter;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling searchComputers");
    }
    
    // create path and map variables
    String localVarPath = "/computers/search".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("multi", "expand", expand));
    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Computers> localVarReturnType = new GenericType<Computers>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
