package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.FileExtensionList;
import com.trendmicro.deepsecurity.model.FileExtensionLists;
import com.trendmicro.deepsecurity.model.SearchFilter;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class FileExtensionListsApi {
  private ApiClient apiClient;

  public FileExtensionListsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public FileExtensionListsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Create a File Extension List
   * Create a new file extension list.
   * @param fileExtensionList The settings of the new file extension list. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return FileExtensionList
   * @throws ApiException if fails to make API call
   */
  public FileExtensionList createFileExtensionList(FileExtensionList fileExtensionList, String apiVersion) throws ApiException {
    Object localVarPostBody = fileExtensionList;
    
    // verify the required parameter 'fileExtensionList' is set
    if (fileExtensionList == null) {
      throw new ApiException(400, "Missing the required parameter 'fileExtensionList' when calling createFileExtensionList");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling createFileExtensionList");
    }
    
    // create path and map variables
    String localVarPath = "/fileextensionlists".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FileExtensionList> localVarReturnType = new GenericType<FileExtensionList>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Delete a File Extension List
   * Delete a file extension list by ID.
   * @param fileExtensionListID The ID number of the file extension list to delete. (required)
   * @param apiVersion The version of the api being called. (required)
   * @throws ApiException if fails to make API call
   */
  public void deleteFileExtensionList(Integer fileExtensionListID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'fileExtensionListID' is set
    if (fileExtensionListID == null) {
      throw new ApiException(400, "Missing the required parameter 'fileExtensionListID' when calling deleteFileExtensionList");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling deleteFileExtensionList");
    }
    
    // create path and map variables
    String localVarPath = "/fileextensionlists/{fileExtensionListID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "fileExtensionListID" + "\\}", apiClient.escapeString(fileExtensionListID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };


    apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, null);
  }
  /**
   * Describe a File Extension List
   * Describe a file extension list by ID.
   * @param fileExtensionListID The ID number of the file extension list to describe. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return FileExtensionList
   * @throws ApiException if fails to make API call
   */
  public FileExtensionList describeFileExtensionList(Integer fileExtensionListID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'fileExtensionListID' is set
    if (fileExtensionListID == null) {
      throw new ApiException(400, "Missing the required parameter 'fileExtensionListID' when calling describeFileExtensionList");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeFileExtensionList");
    }
    
    // create path and map variables
    String localVarPath = "/fileextensionlists/{fileExtensionListID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "fileExtensionListID" + "\\}", apiClient.escapeString(fileExtensionListID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FileExtensionList> localVarReturnType = new GenericType<FileExtensionList>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List File Extension Lists
   * Lists all file extension lists.
   * @param apiVersion The version of the api being called. (required)
   * @return FileExtensionLists
   * @throws ApiException if fails to make API call
   */
  public FileExtensionLists listFileExtensionLists(String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listFileExtensionLists");
    }
    
    // create path and map variables
    String localVarPath = "/fileextensionlists".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FileExtensionLists> localVarReturnType = new GenericType<FileExtensionLists>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify a File Extension List
   * Modify a file extension list by ID. Any unset elements will be left unchanged.
   * @param fileExtensionListID The ID number of the file extension list to modify. (required)
   * @param fileExtensionList The settings of the file extension list to modify. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return FileExtensionList
   * @throws ApiException if fails to make API call
   */
  public FileExtensionList modifyFileExtensionList(Integer fileExtensionListID, FileExtensionList fileExtensionList, String apiVersion) throws ApiException {
    Object localVarPostBody = fileExtensionList;
    
    // verify the required parameter 'fileExtensionListID' is set
    if (fileExtensionListID == null) {
      throw new ApiException(400, "Missing the required parameter 'fileExtensionListID' when calling modifyFileExtensionList");
    }
    
    // verify the required parameter 'fileExtensionList' is set
    if (fileExtensionList == null) {
      throw new ApiException(400, "Missing the required parameter 'fileExtensionList' when calling modifyFileExtensionList");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyFileExtensionList");
    }
    
    // create path and map variables
    String localVarPath = "/fileextensionlists/{fileExtensionListID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "fileExtensionListID" + "\\}", apiClient.escapeString(fileExtensionListID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FileExtensionList> localVarReturnType = new GenericType<FileExtensionList>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Search File Extension Lists
   * Search for file extension lists using optional filters.
   * @param searchFilter A collection of options used to filter the search results. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return FileExtensionLists
   * @throws ApiException if fails to make API call
   */
  public FileExtensionLists searchFileExtensionLists(SearchFilter searchFilter, String apiVersion) throws ApiException {
    Object localVarPostBody = searchFilter;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling searchFileExtensionLists");
    }
    
    // create path and map variables
    String localVarPath = "/fileextensionlists/search".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FileExtensionLists> localVarReturnType = new GenericType<FileExtensionLists>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
