package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.ExceptionRules;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class PolicyDeviceControlExceptionRulesApi {
  private ApiClient apiClient;

  public PolicyDeviceControlExceptionRulesApi() {
    this(Configuration.getDefaultApiClient());
  }

  public PolicyDeviceControlExceptionRulesApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Add Device Exception Rules
   * Assign device exception rules to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param exceptionRules Exception Rules for the device. (required)
   * @param overrides Return only Exception Rules directly related to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return ExceptionRules
   * @throws ApiException if fails to make API call
   */
  public ExceptionRules addExceptionRulesOnPolicy(Integer policyID, ExceptionRules exceptionRules, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = exceptionRules;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling addExceptionRulesOnPolicy");
    }
    
    // verify the required parameter 'exceptionRules' is set
    if (exceptionRules == null) {
      throw new ApiException(400, "Missing the required parameter 'exceptionRules' when calling addExceptionRulesOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling addExceptionRulesOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/devicecontrol/usbdeviceexceptionrules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ExceptionRules> localVarReturnType = new GenericType<ExceptionRules>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Device Exception Rules
   * Lists all device exception rules assigned to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param overrides Return only Exception Rules directly related to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return ExceptionRules
   * @throws ApiException if fails to make API call
   */
  public ExceptionRules listExceptionRulesOnPolicy(Integer policyID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling listExceptionRulesOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listExceptionRulesOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/devicecontrol/usbdeviceexceptionrules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ExceptionRules> localVarReturnType = new GenericType<ExceptionRules>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Remove a Device Exception Rule
   * Unassign a device exception rule from a policy.
   * @param policyID The ID number of the policy. (required)
   * @param exceptionRuleID The ID number of the Exception Rule to delete. (required)
   * @param overrides Return only Exception Rules directly related to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return ExceptionRules
   * @throws ApiException if fails to make API call
   */
  public ExceptionRules removeExceptionRuleOnPolicy(Integer policyID, Long exceptionRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling removeExceptionRuleOnPolicy");
    }
    
    // verify the required parameter 'exceptionRuleID' is set
    if (exceptionRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'exceptionRuleID' when calling removeExceptionRuleOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling removeExceptionRuleOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/devicecontrol/usbdeviceexceptionrules/{exceptionRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "exceptionRuleID" + "\\}", apiClient.escapeString(exceptionRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ExceptionRules> localVarReturnType = new GenericType<ExceptionRules>() {};
    return apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Set Device Exception Rules
   * Set device exception rules assigned to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param exceptionRules Exception Rules for the device. (required)
   * @param overrides Return only Exception Rules directly related to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return ExceptionRules
   * @throws ApiException if fails to make API call
   */
  public ExceptionRules setExceptionRulesOnPolicy(Integer policyID, ExceptionRules exceptionRules, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = exceptionRules;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling setExceptionRulesOnPolicy");
    }
    
    // verify the required parameter 'exceptionRules' is set
    if (exceptionRules == null) {
      throw new ApiException(400, "Missing the required parameter 'exceptionRules' when calling setExceptionRulesOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling setExceptionRulesOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/devicecontrol/usbdeviceexceptionrules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ExceptionRules> localVarReturnType = new GenericType<ExceptionRules>() {};
    return apiClient.invokeAPI(localVarPath, "PUT", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
