package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.FirewallRule;
import com.trendmicro.deepsecurity.model.FirewallRules;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class PolicyFirewallRuleDetailsApi {
  private ApiClient apiClient;

  public PolicyFirewallRuleDetailsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public PolicyFirewallRuleDetailsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Describe a firewall rule
   * Describe a firewall rule including policy-level overrides.
   * @param policyID The ID number of the policy. (required)
   * @param firewallRuleID The ID number of the firewall rule. (required)
   * @param overrides Show only overrides defined for the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return FirewallRule
   * @throws ApiException if fails to make API call
   */
  public FirewallRule describeFirewallRuleOnPolicy(Integer policyID, Integer firewallRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling describeFirewallRuleOnPolicy");
    }
    
    // verify the required parameter 'firewallRuleID' is set
    if (firewallRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'firewallRuleID' when calling describeFirewallRuleOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeFirewallRuleOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/firewall/rules/{firewallRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "firewallRuleID" + "\\}", apiClient.escapeString(firewallRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FirewallRule> localVarReturnType = new GenericType<FirewallRule>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List firewall rules
   * Lists all firewall rules assigned to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param overrides Show only rules assigned to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return FirewallRules
   * @throws ApiException if fails to make API call
   */
  public FirewallRules listFirewallRulesOnPolicy(Integer policyID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling listFirewallRulesOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listFirewallRulesOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/firewall/rules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FirewallRules> localVarReturnType = new GenericType<FirewallRules>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify a firewall rule
   * Modify a firewall rule assigned to a policy. Any unset elements will be left unchanged.
   * @param policyID The ID number of the policy. (required)
   * @param firewallRuleID The ID number of the firewall rule to modify. (required)
   * @param firewallRule The settings of the firewall rule to modify. (required)
   * @param overrides Show only overrides defined for the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return FirewallRule
   * @throws ApiException if fails to make API call
   */
  public FirewallRule modifyFirewallRuleOnPolicy(Integer policyID, Integer firewallRuleID, FirewallRule firewallRule, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = firewallRule;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling modifyFirewallRuleOnPolicy");
    }
    
    // verify the required parameter 'firewallRuleID' is set
    if (firewallRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'firewallRuleID' when calling modifyFirewallRuleOnPolicy");
    }
    
    // verify the required parameter 'firewallRule' is set
    if (firewallRule == null) {
      throw new ApiException(400, "Missing the required parameter 'firewallRule' when calling modifyFirewallRuleOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyFirewallRuleOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/firewall/rules/{firewallRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "firewallRuleID" + "\\}", apiClient.escapeString(firewallRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FirewallRule> localVarReturnType = new GenericType<FirewallRule>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Reset firewall rule overrides
   * Remove all overrides for a firewall rule from a policy.
   * @param policyID The ID number of the policy. (required)
   * @param firewallRuleID The ID number of the firewall rule to reset. (required)
   * @param overrides Show only overrides defined for the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return FirewallRule
   * @throws ApiException if fails to make API call
   */
  public FirewallRule resetFirewallRuleOnPolicy(Integer policyID, Integer firewallRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling resetFirewallRuleOnPolicy");
    }
    
    // verify the required parameter 'firewallRuleID' is set
    if (firewallRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'firewallRuleID' when calling resetFirewallRuleOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling resetFirewallRuleOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/firewall/rules/{firewallRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "firewallRuleID" + "\\}", apiClient.escapeString(firewallRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<FirewallRule> localVarReturnType = new GenericType<FirewallRule>() {};
    return apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
