package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.IntegrityMonitoringRule;
import com.trendmicro.deepsecurity.model.IntegrityMonitoringRules;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class PolicyIntegrityMonitoringRuleDetailsApi {
  private ApiClient apiClient;

  public PolicyIntegrityMonitoringRuleDetailsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public PolicyIntegrityMonitoringRuleDetailsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Describe an integrity monitoring rule
   * Describe an integrity monitoring rule including policy-level overrides.
   * @param policyID The ID number of the policy. (required)
   * @param integrityMonitoringRuleID The ID number of the integrity monitoring rule. (required)
   * @param overrides Show only overrides defined for the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntegrityMonitoringRule
   * @throws ApiException if fails to make API call
   */
  public IntegrityMonitoringRule describeIntegrityMonitoringRuleOnPolicy(Integer policyID, Integer integrityMonitoringRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling describeIntegrityMonitoringRuleOnPolicy");
    }
    
    // verify the required parameter 'integrityMonitoringRuleID' is set
    if (integrityMonitoringRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'integrityMonitoringRuleID' when calling describeIntegrityMonitoringRuleOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeIntegrityMonitoringRuleOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/integritymonitoring/rules/{integrityMonitoringRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "integrityMonitoringRuleID" + "\\}", apiClient.escapeString(integrityMonitoringRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntegrityMonitoringRule> localVarReturnType = new GenericType<IntegrityMonitoringRule>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List integrity monitoring rules
   * Lists all integrity monitoring rules assigned to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param overrides Show only rules assigned to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntegrityMonitoringRules
   * @throws ApiException if fails to make API call
   */
  public IntegrityMonitoringRules listIntegrityMonitoringRulesOnPolicy(Integer policyID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling listIntegrityMonitoringRulesOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listIntegrityMonitoringRulesOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/integritymonitoring/rules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntegrityMonitoringRules> localVarReturnType = new GenericType<IntegrityMonitoringRules>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify an integrity monitoring rule
   * Modify an integrity monitoring rule assigned to a policy. Any unset elements will be left unchanged.
   * @param policyID The ID number of the policy. (required)
   * @param integrityMonitoringRuleID The ID number of the integrity monitoring rule to modify. (required)
   * @param integrityMonitoringRule The settings of the integrity monitoring rule to modify. (required)
   * @param overrides Show only overrides defined for the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntegrityMonitoringRule
   * @throws ApiException if fails to make API call
   */
  public IntegrityMonitoringRule modifyIntegrityMonitoringRuleOnPolicy(Integer policyID, Integer integrityMonitoringRuleID, IntegrityMonitoringRule integrityMonitoringRule, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = integrityMonitoringRule;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling modifyIntegrityMonitoringRuleOnPolicy");
    }
    
    // verify the required parameter 'integrityMonitoringRuleID' is set
    if (integrityMonitoringRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'integrityMonitoringRuleID' when calling modifyIntegrityMonitoringRuleOnPolicy");
    }
    
    // verify the required parameter 'integrityMonitoringRule' is set
    if (integrityMonitoringRule == null) {
      throw new ApiException(400, "Missing the required parameter 'integrityMonitoringRule' when calling modifyIntegrityMonitoringRuleOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyIntegrityMonitoringRuleOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/integritymonitoring/rules/{integrityMonitoringRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "integrityMonitoringRuleID" + "\\}", apiClient.escapeString(integrityMonitoringRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntegrityMonitoringRule> localVarReturnType = new GenericType<IntegrityMonitoringRule>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Reset integrity monitoring rule overrides
   * Remove all overrides for an integrity monitoring rule from a policy.
   * @param policyID The ID number of the policy. (required)
   * @param integrityMonitoringRuleID The ID number of the integrity monitoring rule to reset. (required)
   * @param overrides Show only overrides defined for the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return IntegrityMonitoringRule
   * @throws ApiException if fails to make API call
   */
  public IntegrityMonitoringRule resetIntegrityMonitoringRuleOnPolicy(Integer policyID, Integer integrityMonitoringRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling resetIntegrityMonitoringRuleOnPolicy");
    }
    
    // verify the required parameter 'integrityMonitoringRuleID' is set
    if (integrityMonitoringRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'integrityMonitoringRuleID' when calling resetIntegrityMonitoringRuleOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling resetIntegrityMonitoringRuleOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/integritymonitoring/rules/{integrityMonitoringRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "integrityMonitoringRuleID" + "\\}", apiClient.escapeString(integrityMonitoringRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<IntegrityMonitoringRule> localVarReturnType = new GenericType<IntegrityMonitoringRule>() {};
    return apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
