package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.LogInspectionAssignments;
import com.trendmicro.deepsecurity.model.RuleIDs;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class PolicyLogInspectionRuleAssignmentsRecommendationsApi {
  private ApiClient apiClient;

  public PolicyLogInspectionRuleAssignmentsRecommendationsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public PolicyLogInspectionRuleAssignmentsRecommendationsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Add Log Inspection Rule IDs
   * Assign log inspection rule IDs to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param logInspectionRuleIDs The ID numbers of the log inspection rules to add. (optional)
   * @param overrides Return only rule IDs assigned directly to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return LogInspectionAssignments
   * @throws ApiException if fails to make API call
   */
  public LogInspectionAssignments addLogInspectionRuleIDsToPolicy(Integer policyID, RuleIDs logInspectionRuleIDs, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = logInspectionRuleIDs;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling addLogInspectionRuleIDsToPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling addLogInspectionRuleIDsToPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/loginspection/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<LogInspectionAssignments> localVarReturnType = new GenericType<LogInspectionAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Log Inspection Rule IDs
   * Lists all log inspection rule IDs assigned to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param overrides Return only rule IDs assigned directly to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return LogInspectionAssignments
   * @throws ApiException if fails to make API call
   */
  public LogInspectionAssignments listLogInspectionRuleIDsOnPolicy(Integer policyID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling listLogInspectionRuleIDsOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listLogInspectionRuleIDsOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/loginspection/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<LogInspectionAssignments> localVarReturnType = new GenericType<LogInspectionAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Remove a Log Inspection Rule ID
   * Unassign a log inspection rule ID from a policy.
   * @param policyID The ID number of the policy. (required)
   * @param logInspectionRuleID The ID number of the log inspection rule to delete. (required)
   * @param overrides Return only rule IDs assigned directly to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return LogInspectionAssignments
   * @throws ApiException if fails to make API call
   */
  public LogInspectionAssignments removeLogInspectionRuleIDFromPolicy(Integer policyID, Integer logInspectionRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling removeLogInspectionRuleIDFromPolicy");
    }
    
    // verify the required parameter 'logInspectionRuleID' is set
    if (logInspectionRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'logInspectionRuleID' when calling removeLogInspectionRuleIDFromPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling removeLogInspectionRuleIDFromPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/loginspection/assignments/{logInspectionRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "logInspectionRuleID" + "\\}", apiClient.escapeString(logInspectionRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<LogInspectionAssignments> localVarReturnType = new GenericType<LogInspectionAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Set Log Inspection Rule IDs
   * Set log inspection rule IDs assigned to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param logInspectionRuleIDs The ID numbers of the log inspection rules to set. (optional)
   * @param overrides Return only rule IDs assigned directly to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return LogInspectionAssignments
   * @throws ApiException if fails to make API call
   */
  public LogInspectionAssignments setLogInspectionRuleIDsOnPolicy(Integer policyID, RuleIDs logInspectionRuleIDs, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = logInspectionRuleIDs;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling setLogInspectionRuleIDsOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling setLogInspectionRuleIDsOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/loginspection/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<LogInspectionAssignments> localVarReturnType = new GenericType<LogInspectionAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "PUT", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
