package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.LogInspectionRule;
import com.trendmicro.deepsecurity.model.LogInspectionRules;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class PolicyLogInspectionRuleDetailsApi {
  private ApiClient apiClient;

  public PolicyLogInspectionRuleDetailsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public PolicyLogInspectionRuleDetailsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Describe an log inspection rule
   * Describe an log inspection rule including policy-level overrides.
   * @param policyID The ID number of the policy. (required)
   * @param logInspectionRuleID The ID number of the log inspection rule. (required)
   * @param overrides Show only overrides defined for the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return LogInspectionRule
   * @throws ApiException if fails to make API call
   */
  public LogInspectionRule describeLogInspectionRuleOnPolicy(Integer policyID, Integer logInspectionRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling describeLogInspectionRuleOnPolicy");
    }
    
    // verify the required parameter 'logInspectionRuleID' is set
    if (logInspectionRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'logInspectionRuleID' when calling describeLogInspectionRuleOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeLogInspectionRuleOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/loginspection/rules/{logInspectionRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "logInspectionRuleID" + "\\}", apiClient.escapeString(logInspectionRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<LogInspectionRule> localVarReturnType = new GenericType<LogInspectionRule>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List log inspection rules
   * Lists all log inspection rules assigned to a policy.
   * @param policyID The ID number of the policy. (required)
   * @param overrides Show only rules assigned to the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return LogInspectionRules
   * @throws ApiException if fails to make API call
   */
  public LogInspectionRules listLogInspectionRulesOnPolicy(Integer policyID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling listLogInspectionRulesOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listLogInspectionRulesOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/loginspection/rules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<LogInspectionRules> localVarReturnType = new GenericType<LogInspectionRules>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify an log inspection rule
   * Modify an log inspection rule assigned to a policy. Any unset elements will be left unchanged.
   * @param policyID The ID number of the policy. (required)
   * @param logInspectionRuleID The ID number of the log inspection rule to modify. (required)
   * @param logInspectionRule The settings of the log inspection rule to modify. (required)
   * @param overrides Show only overrides defined for the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return LogInspectionRule
   * @throws ApiException if fails to make API call
   */
  public LogInspectionRule modifyLogInspectionRuleOnPolicy(Integer policyID, Integer logInspectionRuleID, LogInspectionRule logInspectionRule, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = logInspectionRule;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling modifyLogInspectionRuleOnPolicy");
    }
    
    // verify the required parameter 'logInspectionRuleID' is set
    if (logInspectionRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'logInspectionRuleID' when calling modifyLogInspectionRuleOnPolicy");
    }
    
    // verify the required parameter 'logInspectionRule' is set
    if (logInspectionRule == null) {
      throw new ApiException(400, "Missing the required parameter 'logInspectionRule' when calling modifyLogInspectionRuleOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyLogInspectionRuleOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/loginspection/rules/{logInspectionRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "logInspectionRuleID" + "\\}", apiClient.escapeString(logInspectionRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<LogInspectionRule> localVarReturnType = new GenericType<LogInspectionRule>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Reset log inspection rule overrides
   * Remove all overrides for an log inspection rule from a policy.
   * @param policyID The ID number of the policy. (required)
   * @param logInspectionRuleID The ID number of the log inspection rule to reset. (required)
   * @param overrides Show only overrides defined for the current policy. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return LogInspectionRule
   * @throws ApiException if fails to make API call
   */
  public LogInspectionRule resetLogInspectionRuleOnPolicy(Integer policyID, Integer logInspectionRuleID, Boolean overrides, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'policyID' is set
    if (policyID == null) {
      throw new ApiException(400, "Missing the required parameter 'policyID' when calling resetLogInspectionRuleOnPolicy");
    }
    
    // verify the required parameter 'logInspectionRuleID' is set
    if (logInspectionRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'logInspectionRuleID' when calling resetLogInspectionRuleOnPolicy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling resetLogInspectionRuleOnPolicy");
    }
    
    // create path and map variables
    String localVarPath = "/policies/{policyID}/loginspection/rules/{logInspectionRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "policyID" + "\\}", apiClient.escapeString(policyID.toString()))
      .replaceAll("\\{" + "logInspectionRuleID" + "\\}", apiClient.escapeString(logInspectionRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "overrides", overrides));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<LogInspectionRule> localVarReturnType = new GenericType<LogInspectionRule>() {};
    return apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
