package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.Proxies;
import com.trendmicro.deepsecurity.model.Proxy;
import com.trendmicro.deepsecurity.model.SearchFilter;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class ProxiesApi {
  private ApiClient apiClient;

  public ProxiesApi() {
    this(Configuration.getDefaultApiClient());
  }

  public ProxiesApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Create a Proxy
   * Create a new proxy.
   * @param proxy The settings of the proxy to modify. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return Proxy
   * @throws ApiException if fails to make API call
   */
  public Proxy createProxy(Proxy proxy, String apiVersion) throws ApiException {
    Object localVarPostBody = proxy;
    
    // verify the required parameter 'proxy' is set
    if (proxy == null) {
      throw new ApiException(400, "Missing the required parameter 'proxy' when calling createProxy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling createProxy");
    }
    
    // create path and map variables
    String localVarPath = "/proxies".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Proxy> localVarReturnType = new GenericType<Proxy>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Delete a Proxy
   * Delete a proxy by ID.
   * @param proxyID The ID number of the proxy to delete. (required)
   * @param apiVersion The version of the api being called. (required)
   * @throws ApiException if fails to make API call
   */
  public void deleteProxy(Integer proxyID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'proxyID' is set
    if (proxyID == null) {
      throw new ApiException(400, "Missing the required parameter 'proxyID' when calling deleteProxy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling deleteProxy");
    }
    
    // create path and map variables
    String localVarPath = "/proxies/{proxyID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "proxyID" + "\\}", apiClient.escapeString(proxyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };


    apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, null);
  }
  /**
   * Describe a Proxy
   * Describe a proxy by ID.
   * @param proxyID The ID number of the proxy to describe. (required)
   * @param proxyType Type of proxy (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return Proxy
   * @throws ApiException if fails to make API call
   */
  public Proxy describeProxy(Integer proxyID, String proxyType, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'proxyID' is set
    if (proxyID == null) {
      throw new ApiException(400, "Missing the required parameter 'proxyID' when calling describeProxy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeProxy");
    }
    
    // create path and map variables
    String localVarPath = "/proxies/{proxyID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "proxyID" + "\\}", apiClient.escapeString(proxyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "proxyType", proxyType));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Proxy> localVarReturnType = new GenericType<Proxy>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Proxies
   * Lists all proxies.
   * @param includesSG includes sg settings. default: false (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return Proxies
   * @throws ApiException if fails to make API call
   */
  public Proxies listProxies(Boolean includesSG, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listProxies");
    }
    
    // create path and map variables
    String localVarPath = "/proxies".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "includesSG", includesSG));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Proxies> localVarReturnType = new GenericType<Proxies>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify a Proxy
   * Modify a proxy by ID. Any unset elements will be left unchanged.
   * @param proxyID The ID number of the proxy to modify. (required)
   * @param proxy The settings of the proxy to modify. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return Proxy
   * @throws ApiException if fails to make API call
   */
  public Proxy modifyProxy(Integer proxyID, Proxy proxy, String apiVersion) throws ApiException {
    Object localVarPostBody = proxy;
    
    // verify the required parameter 'proxyID' is set
    if (proxyID == null) {
      throw new ApiException(400, "Missing the required parameter 'proxyID' when calling modifyProxy");
    }
    
    // verify the required parameter 'proxy' is set
    if (proxy == null) {
      throw new ApiException(400, "Missing the required parameter 'proxy' when calling modifyProxy");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyProxy");
    }
    
    // create path and map variables
    String localVarPath = "/proxies/{proxyID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "proxyID" + "\\}", apiClient.escapeString(proxyID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Proxy> localVarReturnType = new GenericType<Proxy>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Search Proxies
   * Search for proxies using optional filters.
   * @param searchFilter A collection of options used to filter the search results. (optional)
   * @param includesSG includes sg settings. default: false (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return Proxies
   * @throws ApiException if fails to make API call
   */
  public Proxies searchProxies(SearchFilter searchFilter, Boolean includesSG, String apiVersion) throws ApiException {
    Object localVarPostBody = searchFilter;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling searchProxies");
    }
    
    // create path and map variables
    String localVarPath = "/proxies/search".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "includesSG", includesSG));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Proxies> localVarReturnType = new GenericType<Proxies>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
