package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.ApplicationControlRule;
import com.trendmicro.deepsecurity.model.ApplicationControlRules;
import com.trendmicro.deepsecurity.model.Ruleset;
import com.trendmicro.deepsecurity.model.Rulesets;
import com.trendmicro.deepsecurity.model.SearchFilter;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class RulesetsApi {
  private ApiClient apiClient;

  public RulesetsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public RulesetsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Create a Shared Ruleset
   * Create a new shared ruleset.
   * @param ruleset The settings of the new ruleset. (required)
   * @param softwareinventoryid ID of the software inventory to base the ruleset on. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return Ruleset
   * @throws ApiException if fails to make API call
   */
  public Ruleset createRuleset(Ruleset ruleset, Long softwareinventoryid, String apiVersion) throws ApiException {
    Object localVarPostBody = ruleset;
    
    // verify the required parameter 'ruleset' is set
    if (ruleset == null) {
      throw new ApiException(400, "Missing the required parameter 'ruleset' when calling createRuleset");
    }
    
    // verify the required parameter 'softwareinventoryid' is set
    if (softwareinventoryid == null) {
      throw new ApiException(400, "Missing the required parameter 'softwareinventoryid' when calling createRuleset");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling createRuleset");
    }
    
    // create path and map variables
    String localVarPath = "/rulesets".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "softwareinventoryid", softwareinventoryid));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Ruleset> localVarReturnType = new GenericType<Ruleset>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Delete a Ruleset
   * Delete a ruleset by ID.
   * @param rulesetID The ID number of the ruleset to delete. (required)
   * @param apiVersion The version of the api being called. (required)
   * @throws ApiException if fails to make API call
   */
  public void deleteRuleset(Long rulesetID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'rulesetID' is set
    if (rulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'rulesetID' when calling deleteRuleset");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling deleteRuleset");
    }
    
    // create path and map variables
    String localVarPath = "/rulesets/{rulesetID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "rulesetID" + "\\}", apiClient.escapeString(rulesetID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };


    apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, null);
  }
  /**
   * Delete a Ruleset Rule
   * Delete a ruleset rule by ID.
   * @param rulesetID The ID number of the ruleset. (required)
   * @param ruleID The ID number of the rule to delete. (required)
   * @param apiVersion The version of the api being called. (required)
   * @throws ApiException if fails to make API call
   */
  public void deleteRulesetRule(Long rulesetID, Long ruleID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'rulesetID' is set
    if (rulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'rulesetID' when calling deleteRulesetRule");
    }
    
    // verify the required parameter 'ruleID' is set
    if (ruleID == null) {
      throw new ApiException(400, "Missing the required parameter 'ruleID' when calling deleteRulesetRule");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling deleteRulesetRule");
    }
    
    // create path and map variables
    String localVarPath = "/rulesets/{rulesetID}/rules/{ruleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "rulesetID" + "\\}", apiClient.escapeString(rulesetID.toString()))
      .replaceAll("\\{" + "ruleID" + "\\}", apiClient.escapeString(ruleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };


    apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, null);
  }
  /**
   * Describe a Ruleset
   * Describe a ruleset by ID.
   * @param rulesetID The ID number of the ruleset to describe. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return Ruleset
   * @throws ApiException if fails to make API call
   */
  public Ruleset describeRuleset(Long rulesetID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'rulesetID' is set
    if (rulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'rulesetID' when calling describeRuleset");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeRuleset");
    }
    
    // create path and map variables
    String localVarPath = "/rulesets/{rulesetID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "rulesetID" + "\\}", apiClient.escapeString(rulesetID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Ruleset> localVarReturnType = new GenericType<Ruleset>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Describe a Ruleset Rule
   * Describe a ruleset rule by ID.
   * @param rulesetID The ID number of the ruleset. (required)
   * @param ruleID The ID number of the rule to describe. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return ApplicationControlRule
   * @throws ApiException if fails to make API call
   */
  public ApplicationControlRule describeRulesetRule(Long rulesetID, Long ruleID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'rulesetID' is set
    if (rulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'rulesetID' when calling describeRulesetRule");
    }
    
    // verify the required parameter 'ruleID' is set
    if (ruleID == null) {
      throw new ApiException(400, "Missing the required parameter 'ruleID' when calling describeRulesetRule");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeRulesetRule");
    }
    
    // create path and map variables
    String localVarPath = "/rulesets/{rulesetID}/rules/{ruleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "rulesetID" + "\\}", apiClient.escapeString(rulesetID.toString()))
      .replaceAll("\\{" + "ruleID" + "\\}", apiClient.escapeString(ruleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ApplicationControlRule> localVarReturnType = new GenericType<ApplicationControlRule>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Ruleset Rules
   * List all rules of a ruleset by ID.
   * @param rulesetID The ID number of the ruleset. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return ApplicationControlRules
   * @throws ApiException if fails to make API call
   */
  public ApplicationControlRules listRulesetRules(Long rulesetID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'rulesetID' is set
    if (rulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'rulesetID' when calling listRulesetRules");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listRulesetRules");
    }
    
    // create path and map variables
    String localVarPath = "/rulesets/{rulesetID}/rules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "rulesetID" + "\\}", apiClient.escapeString(rulesetID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ApplicationControlRules> localVarReturnType = new GenericType<ApplicationControlRules>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Rulesets
   * Lists all rulesets.
   * @param apiVersion The version of the api being called. (required)
   * @return Rulesets
   * @throws ApiException if fails to make API call
   */
  public Rulesets listRulesets(String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listRulesets");
    }
    
    // create path and map variables
    String localVarPath = "/rulesets".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Rulesets> localVarReturnType = new GenericType<Rulesets>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify a Ruleset Rule
   * Modify a ruleset rule by ID.
   * @param rulesetID The ID number of the ruleset. (required)
   * @param ruleID The ID number of the rule to modify. (required)
   * @param rule The settings of the rule to modify. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return ApplicationControlRule
   * @throws ApiException if fails to make API call
   */
  public ApplicationControlRule modifyRulesetRule(Long rulesetID, Long ruleID, ApplicationControlRule rule, String apiVersion) throws ApiException {
    Object localVarPostBody = rule;
    
    // verify the required parameter 'rulesetID' is set
    if (rulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'rulesetID' when calling modifyRulesetRule");
    }
    
    // verify the required parameter 'ruleID' is set
    if (ruleID == null) {
      throw new ApiException(400, "Missing the required parameter 'ruleID' when calling modifyRulesetRule");
    }
    
    // verify the required parameter 'rule' is set
    if (rule == null) {
      throw new ApiException(400, "Missing the required parameter 'rule' when calling modifyRulesetRule");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyRulesetRule");
    }
    
    // create path and map variables
    String localVarPath = "/rulesets/{rulesetID}/rules/{ruleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "rulesetID" + "\\}", apiClient.escapeString(rulesetID.toString()))
      .replaceAll("\\{" + "ruleID" + "\\}", apiClient.escapeString(ruleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ApplicationControlRule> localVarReturnType = new GenericType<ApplicationControlRule>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Search Ruleset Rules
   * Search for ruleset rules using optional filters.
   * @param rulesetID The ID number of the ruleset. (required)
   * @param searchFilter A collection of options used to filter the search results. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return ApplicationControlRules
   * @throws ApiException if fails to make API call
   */
  public ApplicationControlRules searchRulesetRules(Long rulesetID, SearchFilter searchFilter, String apiVersion) throws ApiException {
    Object localVarPostBody = searchFilter;
    
    // verify the required parameter 'rulesetID' is set
    if (rulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'rulesetID' when calling searchRulesetRules");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling searchRulesetRules");
    }
    
    // create path and map variables
    String localVarPath = "/rulesets/{rulesetID}/rules/search".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "rulesetID" + "\\}", apiClient.escapeString(rulesetID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ApplicationControlRules> localVarReturnType = new GenericType<ApplicationControlRules>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Search Rulesets
   * Search for rulesets using optional filters.
   * @param searchFilter A collection of options used to filter the search results. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return Rulesets
   * @throws ApiException if fails to make API call
   */
  public Rulesets searchRulesets(SearchFilter searchFilter, String apiVersion) throws ApiException {
    Object localVarPostBody = searchFilter;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling searchRulesets");
    }
    
    // create path and map variables
    String localVarPath = "/rulesets/search".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Rulesets> localVarReturnType = new GenericType<Rulesets>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
