package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.SearchFilter;
import com.trendmicro.deepsecurity.model.SoftwareChange;
import com.trendmicro.deepsecurity.model.SoftwareChangeReview;
import com.trendmicro.deepsecurity.model.SoftwareChanges;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class SoftwareChangesApi {
  private ApiClient apiClient;

  public SoftwareChangesApi() {
    this(Configuration.getDefaultApiClient());
  }

  public SoftwareChangesApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Describe a software change
   * Describe a software change by ID.
   * @param softwareChangeID The ID number of the software change to describe. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return SoftwareChange
   * @throws ApiException if fails to make API call
   */
  public SoftwareChange describeSoftwareChange(Long softwareChangeID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'softwareChangeID' is set
    if (softwareChangeID == null) {
      throw new ApiException(400, "Missing the required parameter 'softwareChangeID' when calling describeSoftwareChange");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeSoftwareChange");
    }
    
    // create path and map variables
    String localVarPath = "/softwarechanges/{softwareChangeID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "softwareChangeID" + "\\}", apiClient.escapeString(softwareChangeID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<SoftwareChange> localVarReturnType = new GenericType<SoftwareChange>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List software changes
   * Lists all software changes.
   * @param apiVersion The version of the api being called. (required)
   * @return SoftwareChanges
   * @throws ApiException if fails to make API call
   */
  public SoftwareChanges listSoftwareChanges(String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listSoftwareChanges");
    }
    
    // create path and map variables
    String localVarPath = "/softwarechanges".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<SoftwareChanges> localVarReturnType = new GenericType<SoftwareChanges>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Review software changes
   * Review software changes by given ID list.
   * @param softwareChangeReview The software change review settings. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return SoftwareChangeReview
   * @throws ApiException if fails to make API call
   */
  public SoftwareChangeReview reviewSoftwareChanges(SoftwareChangeReview softwareChangeReview, String apiVersion) throws ApiException {
    Object localVarPostBody = softwareChangeReview;
    
    // verify the required parameter 'softwareChangeReview' is set
    if (softwareChangeReview == null) {
      throw new ApiException(400, "Missing the required parameter 'softwareChangeReview' when calling reviewSoftwareChanges");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling reviewSoftwareChanges");
    }
    
    // create path and map variables
    String localVarPath = "/softwarechanges/review".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<SoftwareChangeReview> localVarReturnType = new GenericType<SoftwareChangeReview>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Search software changes
   * Search for software changes using optional filters.
   * @param searchFilter A collection of options used to filter the search results. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return SoftwareChanges
   * @throws ApiException if fails to make API call
   */
  public SoftwareChanges searchSoftwareChanges(SearchFilter searchFilter, String apiVersion) throws ApiException {
    Object localVarPostBody = searchFilter;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling searchSoftwareChanges");
    }
    
    // create path and map variables
    String localVarPath = "/softwarechanges/search".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<SoftwareChanges> localVarReturnType = new GenericType<SoftwareChanges>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
