package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.InventoryItem;
import com.trendmicro.deepsecurity.model.InventoryItems;
import com.trendmicro.deepsecurity.model.SearchFilter;
import com.trendmicro.deepsecurity.model.SoftwareInventories;
import com.trendmicro.deepsecurity.model.SoftwareInventory;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class SoftwareInventoriesApi {
  private ApiClient apiClient;

  public SoftwareInventoriesApi() {
    this(Configuration.getDefaultApiClient());
  }

  public SoftwareInventoriesApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Create a Software Inventory
   * Request the creation of a new software inventory to use in creating shared rulesets.
   * @param softwareInventory The settings of the new software inventory. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return SoftwareInventory
   * @throws ApiException if fails to make API call
   */
  public SoftwareInventory createSoftwareInventory(SoftwareInventory softwareInventory, String apiVersion) throws ApiException {
    Object localVarPostBody = softwareInventory;
    
    // verify the required parameter 'softwareInventory' is set
    if (softwareInventory == null) {
      throw new ApiException(400, "Missing the required parameter 'softwareInventory' when calling createSoftwareInventory");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling createSoftwareInventory");
    }
    
    // create path and map variables
    String localVarPath = "/softwareinventories".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<SoftwareInventory> localVarReturnType = new GenericType<SoftwareInventory>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Delete a Software Inventory
   * Delete a software inventory by ID.
   * @param softwareInventoryID The ID number of the software inventory to delete. (required)
   * @param apiVersion The version of the api being called. (required)
   * @throws ApiException if fails to make API call
   */
  public void deleteSoftwareInventory(Long softwareInventoryID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'softwareInventoryID' is set
    if (softwareInventoryID == null) {
      throw new ApiException(400, "Missing the required parameter 'softwareInventoryID' when calling deleteSoftwareInventory");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling deleteSoftwareInventory");
    }
    
    // create path and map variables
    String localVarPath = "/softwareinventories/{softwareInventoryID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "softwareInventoryID" + "\\}", apiClient.escapeString(softwareInventoryID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };


    apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, null);
  }
  /**
   * Describe a Software Inventory
   * Describe a software inventory by ID.
   * @param softwareInventoryID The ID number of the software inventory to describe. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return SoftwareInventory
   * @throws ApiException if fails to make API call
   */
  public SoftwareInventory describeSoftwareInventory(Long softwareInventoryID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'softwareInventoryID' is set
    if (softwareInventoryID == null) {
      throw new ApiException(400, "Missing the required parameter 'softwareInventoryID' when calling describeSoftwareInventory");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeSoftwareInventory");
    }
    
    // create path and map variables
    String localVarPath = "/softwareinventories/{softwareInventoryID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "softwareInventoryID" + "\\}", apiClient.escapeString(softwareInventoryID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<SoftwareInventory> localVarReturnType = new GenericType<SoftwareInventory>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Describe a Software Inventory Item
   * Describe a software inventory item by ID.
   * @param softwareInventoryID The ID number of the software inventory. (required)
   * @param inventoryItemID The ID number of the inventory item to describe. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return InventoryItem
   * @throws ApiException if fails to make API call
   */
  public InventoryItem describeSoftwareInventoryItem(Long softwareInventoryID, Long inventoryItemID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'softwareInventoryID' is set
    if (softwareInventoryID == null) {
      throw new ApiException(400, "Missing the required parameter 'softwareInventoryID' when calling describeSoftwareInventoryItem");
    }
    
    // verify the required parameter 'inventoryItemID' is set
    if (inventoryItemID == null) {
      throw new ApiException(400, "Missing the required parameter 'inventoryItemID' when calling describeSoftwareInventoryItem");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeSoftwareInventoryItem");
    }
    
    // create path and map variables
    String localVarPath = "/softwareinventories/{softwareInventoryID}/items/{inventoryItemID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "softwareInventoryID" + "\\}", apiClient.escapeString(softwareInventoryID.toString()))
      .replaceAll("\\{" + "inventoryItemID" + "\\}", apiClient.escapeString(inventoryItemID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<InventoryItem> localVarReturnType = new GenericType<InventoryItem>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Software Inventories
   * Lists all software inventories.
   * @param apiVersion The version of the api being called. (required)
   * @return SoftwareInventories
   * @throws ApiException if fails to make API call
   */
  public SoftwareInventories listSoftwareInventories(String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listSoftwareInventories");
    }
    
    // create path and map variables
    String localVarPath = "/softwareinventories".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<SoftwareInventories> localVarReturnType = new GenericType<SoftwareInventories>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Software Inventory Items
   * Lists all items of a software inventory.
   * @param softwareInventoryID The ID number of the software inventory. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return InventoryItems
   * @throws ApiException if fails to make API call
   */
  public InventoryItems listSoftwareInventoryItems(Long softwareInventoryID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'softwareInventoryID' is set
    if (softwareInventoryID == null) {
      throw new ApiException(400, "Missing the required parameter 'softwareInventoryID' when calling listSoftwareInventoryItems");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listSoftwareInventoryItems");
    }
    
    // create path and map variables
    String localVarPath = "/softwareinventories/{softwareInventoryID}/items".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "softwareInventoryID" + "\\}", apiClient.escapeString(softwareInventoryID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<InventoryItems> localVarReturnType = new GenericType<InventoryItems>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Search Software Inventories
   * Search for a software inventory using optional filters.
   * @param searchFilter A collection of options used to filter the search results. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return SoftwareInventories
   * @throws ApiException if fails to make API call
   */
  public SoftwareInventories searchSoftwareInventories(SearchFilter searchFilter, String apiVersion) throws ApiException {
    Object localVarPostBody = searchFilter;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling searchSoftwareInventories");
    }
    
    // create path and map variables
    String localVarPath = "/softwareinventories/search".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<SoftwareInventories> localVarReturnType = new GenericType<SoftwareInventories>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Search Software Inventory Items
   * Search for items of a software inventory using optional filters.
   * @param softwareInventoryID The ID number of the software inventory. (required)
   * @param searchFilter A collection of options used to filter the search results. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return InventoryItems
   * @throws ApiException if fails to make API call
   */
  public InventoryItems searchSoftwareInventoryItems(Long softwareInventoryID, SearchFilter searchFilter, String apiVersion) throws ApiException {
    Object localVarPostBody = searchFilter;
    
    // verify the required parameter 'softwareInventoryID' is set
    if (softwareInventoryID == null) {
      throw new ApiException(400, "Missing the required parameter 'softwareInventoryID' when calling searchSoftwareInventoryItems");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling searchSoftwareInventoryItems");
    }
    
    // create path and map variables
    String localVarPath = "/softwareinventories/{softwareInventoryID}/items/search".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "softwareInventoryID" + "\\}", apiClient.escapeString(softwareInventoryID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<InventoryItems> localVarReturnType = new GenericType<InventoryItems>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
