package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.ApiKey;
import com.trendmicro.deepsecurity.model.SearchFilter;
import com.trendmicro.deepsecurity.model.Tenant;
import com.trendmicro.deepsecurity.model.Tenants;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class TenantsApi {
  private ApiClient apiClient;

  public TenantsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public TenantsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Create a Tenant
   * Create a new tenant.
   * @param tenant The settings of the new tenant. (required)
   * @param bypassTenantCache Indicates whether to bypass the tenant cache or not. Default value is false. (optional, default to false)
   * @param confirmationRequired Indicates whether a confirmation email is required or not. Default value is true. (optional, default to true)
   * @param asynchronous Indicates whether it&#39;s an asynchronous call. Default value is false. (optional, default to false)
   * @param apiVersion The version of the api being called. (required)
   * @return Tenant
   * @throws ApiException if fails to make API call
   */
  public Tenant createTenant(Tenant tenant, Boolean bypassTenantCache, Boolean confirmationRequired, Boolean asynchronous, String apiVersion) throws ApiException {
    Object localVarPostBody = tenant;
    
    // verify the required parameter 'tenant' is set
    if (tenant == null) {
      throw new ApiException(400, "Missing the required parameter 'tenant' when calling createTenant");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling createTenant");
    }
    
    // create path and map variables
    String localVarPath = "/tenants".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();

    localVarQueryParams.addAll(apiClient.parameterToPairs("", "bypassTenantCache", bypassTenantCache));
    localVarQueryParams.addAll(apiClient.parameterToPairs("", "confirmationRequired", confirmationRequired));
    localVarQueryParams.addAll(apiClient.parameterToPairs("", "asynchronous", asynchronous));

    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Tenant> localVarReturnType = new GenericType<Tenant>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Delete a Tenant
   * Delete a tenant by ID.
   * @param tenantID The ID number of the tenant to delete. (required)
   * @param apiVersion The version of the api being called. (required)
   * @throws ApiException if fails to make API call
   */
  public void deleteTenant(Integer tenantID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'tenantID' is set
    if (tenantID == null) {
      throw new ApiException(400, "Missing the required parameter 'tenantID' when calling deleteTenant");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling deleteTenant");
    }
    
    // create path and map variables
    String localVarPath = "/tenants/{tenantID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "tenantID" + "\\}", apiClient.escapeString(tenantID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };


    apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, null);
  }
  /**
   * Describe a Tenant
   * Describe a tenant by ID.
   * @param tenantID The ID number of the tenant to describe. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return Tenant
   * @throws ApiException if fails to make API call
   */
  public Tenant describeTenant(Integer tenantID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'tenantID' is set
    if (tenantID == null) {
      throw new ApiException(400, "Missing the required parameter 'tenantID' when calling describeTenant");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeTenant");
    }
    
    // create path and map variables
    String localVarPath = "/tenants/{tenantID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "tenantID" + "\\}", apiClient.escapeString(tenantID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Tenant> localVarReturnType = new GenericType<Tenant>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Generate an API Key for the Tenant
   * Generate a new API key for a tenant from the primary account. This key will be expired after 6 hours if no expiryDate set.
   * @param tenantID The ID number of the tenant the key is being generated for. (required)
   * @param apiKey The settings of the new API key. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return ApiKey
   * @throws ApiException if fails to make API call
   */
  public ApiKey generateTenantApiSecretKey(Integer tenantID, ApiKey apiKey, String apiVersion) throws ApiException {
    Object localVarPostBody = apiKey;
    
    // verify the required parameter 'tenantID' is set
    if (tenantID == null) {
      throw new ApiException(400, "Missing the required parameter 'tenantID' when calling generateTenantApiSecretKey");
    }
    
    // verify the required parameter 'apiKey' is set
    if (apiKey == null) {
      throw new ApiException(400, "Missing the required parameter 'apiKey' when calling generateTenantApiSecretKey");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling generateTenantApiSecretKey");
    }
    
    // create path and map variables
    String localVarPath = "/tenants/{tenantID}/apikeys".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "tenantID" + "\\}", apiClient.escapeString(tenantID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ApiKey> localVarReturnType = new GenericType<ApiKey>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Tenants
   * Lists all tenants.
   * @param apiVersion The version of the api being called. (required)
   * @return Tenants
   * @throws ApiException if fails to make API call
   */
  public Tenants listTenants(String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listTenants");
    }
    
    // create path and map variables
    String localVarPath = "/tenants".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Tenants> localVarReturnType = new GenericType<Tenants>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify a Tenant
   * Modify a tenant by ID. Any unset elements will be left unchanged.
   * @param tenantID The ID number of the tenant to modify. (required)
   * @param tenant The settings of the tenant to modify. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return Tenant
   * @throws ApiException if fails to make API call
   */
  public Tenant modifyTenant(Integer tenantID, Tenant tenant, String apiVersion) throws ApiException {
    Object localVarPostBody = tenant;
    
    // verify the required parameter 'tenantID' is set
    if (tenantID == null) {
      throw new ApiException(400, "Missing the required parameter 'tenantID' when calling modifyTenant");
    }
    
    // verify the required parameter 'tenant' is set
    if (tenant == null) {
      throw new ApiException(400, "Missing the required parameter 'tenant' when calling modifyTenant");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyTenant");
    }
    
    // create path and map variables
    String localVarPath = "/tenants/{tenantID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "tenantID" + "\\}", apiClient.escapeString(tenantID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Tenant> localVarReturnType = new GenericType<Tenant>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Search Tenants
   * Search for tenants using optional filters.
   * @param searchFilter A collection of options used to filter the search results. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return Tenants
   * @throws ApiException if fails to make API call
   */
  public Tenants searchTenants(SearchFilter searchFilter, String apiVersion) throws ApiException {
    Object localVarPostBody = searchFilter;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling searchTenants");
    }
    
    // create path and map variables
    String localVarPath = "/tenants/search".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<Tenants> localVarReturnType = new GenericType<Tenants>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
