package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.RuleLongIDs;
import com.trendmicro.deepsecurity.model.TrustRuleIDs;
import com.trendmicro.deepsecurity.model.TrustRules;
import com.trendmicro.deepsecurity.model.TrustRuleset;
import com.trendmicro.deepsecurity.model.TrustRulesetAssignments;
import com.trendmicro.deepsecurity.model.TrustRulesetUpdateRequest;
import com.trendmicro.deepsecurity.model.TrustRulesets;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class TrustRulesetsApi {
  private ApiClient apiClient;

  public TrustRulesetsApi() {
    this(Configuration.getDefaultApiClient());
  }

  public TrustRulesetsApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Add Trust Rule IDs
   * Assign additional trust rule IDs to a trust ruleset.
   * @param acTrustRulesetID The ID number of the trust ruleset. (required)
   * @param body The ID numbers of the trust rules to add. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return TrustRuleIDs
   * @throws ApiException if fails to make API call
   */
  public TrustRuleIDs addTrustRules(Long acTrustRulesetID, RuleLongIDs body, String apiVersion) throws ApiException {
    Object localVarPostBody = body;
    
    // verify the required parameter 'acTrustRulesetID' is set
    if (acTrustRulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'acTrustRulesetID' when calling addTrustRules");
    }
    
    // verify the required parameter 'body' is set
    if (body == null) {
      throw new ApiException(400, "Missing the required parameter 'body' when calling addTrustRules");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling addTrustRules");
    }
    
    // create path and map variables
    String localVarPath = "/applicationcontroltrustrulesets/{acTrustRulesetID}/rules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "acTrustRulesetID" + "\\}", apiClient.escapeString(acTrustRulesetID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<TrustRuleIDs> localVarReturnType = new GenericType<TrustRuleIDs>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Create a Trust Ruleset
   * Create a new trust ruleset.
   * @param trustruleset The settings of the new trust ruleset. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return TrustRuleset
   * @throws ApiException if fails to make API call
   */
  public TrustRuleset createTrustRuleset(TrustRuleset trustruleset, String apiVersion) throws ApiException {
    Object localVarPostBody = trustruleset;
    
    // verify the required parameter 'trustruleset' is set
    if (trustruleset == null) {
      throw new ApiException(400, "Missing the required parameter 'trustruleset' when calling createTrustRuleset");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling createTrustRuleset");
    }
    
    // create path and map variables
    String localVarPath = "/applicationcontroltrustrulesets".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<TrustRuleset> localVarReturnType = new GenericType<TrustRuleset>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Delete a Trust Rule from a Trust Ruleset
   * Delete a single trust rule from a trust ruleset by the trust ruleset ID and the trust rule ID.
   * @param acTrustRulesetID The ID number of the trust ruleset. (required)
   * @param acTrustRuleID The ID number of the trust rule to delete. (required)
   * @param apiVersion The version of the api being called. (required)
   * @throws ApiException if fails to make API call
   */
  public void deleteTrustRuleFromTrustRuleset(Long acTrustRulesetID, Long acTrustRuleID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'acTrustRulesetID' is set
    if (acTrustRulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'acTrustRulesetID' when calling deleteTrustRuleFromTrustRuleset");
    }
    
    // verify the required parameter 'acTrustRuleID' is set
    if (acTrustRuleID == null) {
      throw new ApiException(400, "Missing the required parameter 'acTrustRuleID' when calling deleteTrustRuleFromTrustRuleset");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling deleteTrustRuleFromTrustRuleset");
    }
    
    // create path and map variables
    String localVarPath = "/applicationcontroltrustrulesets/{acTrustRulesetID}/rules/{acTrustRuleID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "acTrustRulesetID" + "\\}", apiClient.escapeString(acTrustRulesetID.toString()))
      .replaceAll("\\{" + "acTrustRuleID" + "\\}", apiClient.escapeString(acTrustRuleID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };


    apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, null);
  }
  /**
   * Delete a Trust Ruleset
   * Delete a trust ruleset by ID.
   * @param acTrustRulesetID The ID number of the trust ruleset to delete. (required)
   * @param apiVersion The version of the api being called. (required)
   * @throws ApiException if fails to make API call
   */
  public void deleteTrustRuleset(Long acTrustRulesetID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'acTrustRulesetID' is set
    if (acTrustRulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'acTrustRulesetID' when calling deleteTrustRuleset");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling deleteTrustRuleset");
    }
    
    // create path and map variables
    String localVarPath = "/applicationcontroltrustrulesets/{acTrustRulesetID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "acTrustRulesetID" + "\\}", apiClient.escapeString(acTrustRulesetID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };


    apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, null);
  }
  /**
   * Describe a Trust Ruleset
   * Describe a trust ruleset by ID.
   * @param acTrustRulesetID The ID number of the trust ruleset to describe. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return TrustRuleset
   * @throws ApiException if fails to make API call
   */
  public TrustRuleset describeTrustRuleset(Long acTrustRulesetID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'acTrustRulesetID' is set
    if (acTrustRulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'acTrustRulesetID' when calling describeTrustRuleset");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeTrustRuleset");
    }
    
    // create path and map variables
    String localVarPath = "/applicationcontroltrustrulesets/{acTrustRulesetID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "acTrustRulesetID" + "\\}", apiClient.escapeString(acTrustRulesetID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<TrustRuleset> localVarReturnType = new GenericType<TrustRuleset>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List a Trust Ruleset Assignment
   * List a trust ruleset&#39;s computer and policy assignment by the trust ruleset ID.
   * @param acTrustRulesetID The ID of the trust ruleset (required)
   * @param apiVersion The version of the api being called. (required)
   * @return TrustRulesetAssignments
   * @throws ApiException if fails to make API call
   */
  public TrustRulesetAssignments listTrustRulesetAssignments(Long acTrustRulesetID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'acTrustRulesetID' is set
    if (acTrustRulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'acTrustRulesetID' when calling listTrustRulesetAssignments");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listTrustRulesetAssignments");
    }
    
    // create path and map variables
    String localVarPath = "/applicationcontroltrustrulesets/{acTrustRulesetID}/assignments".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "acTrustRulesetID" + "\\}", apiClient.escapeString(acTrustRulesetID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<TrustRulesetAssignments> localVarReturnType = new GenericType<TrustRulesetAssignments>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Trust Rules in a Trust Ruleset
   * List all trust rules in a trust ruleset by trust ruleset ID.
   * @param acTrustRulesetID The ID of the trust ruleset. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return TrustRules
   * @throws ApiException if fails to make API call
   */
  public TrustRules listTrustRulesetRules(Long acTrustRulesetID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'acTrustRulesetID' is set
    if (acTrustRulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'acTrustRulesetID' when calling listTrustRulesetRules");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listTrustRulesetRules");
    }
    
    // create path and map variables
    String localVarPath = "/applicationcontroltrustrulesets/{acTrustRulesetID}/rules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "acTrustRulesetID" + "\\}", apiClient.escapeString(acTrustRulesetID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<TrustRules> localVarReturnType = new GenericType<TrustRules>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Trust Rulesets
   * List all trust rulesets.
   * @param apiVersion The version of the api being called. (required)
   * @return TrustRulesets
   * @throws ApiException if fails to make API call
   */
  public TrustRulesets listTrustRulesets(String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listTrustRulesets");
    }
    
    // create path and map variables
    String localVarPath = "/applicationcontroltrustrulesets".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<TrustRulesets> localVarReturnType = new GenericType<TrustRulesets>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify a Trust Ruleset
   * Modify a trust ruleset&#39;s attributes by trust ruleset ID, including trust rule assignment.
   * @param acTrustRulesetID The ID number of the trust ruleset to modify. (required)
   * @param body The attributes of the trust ruleset to modify. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return TrustRuleset
   * @throws ApiException if fails to make API call
   */
  public TrustRuleset modifyTrustRuleset(Long acTrustRulesetID, TrustRulesetUpdateRequest body, String apiVersion) throws ApiException {
    Object localVarPostBody = body;
    
    // verify the required parameter 'acTrustRulesetID' is set
    if (acTrustRulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'acTrustRulesetID' when calling modifyTrustRuleset");
    }
    
    // verify the required parameter 'body' is set
    if (body == null) {
      throw new ApiException(400, "Missing the required parameter 'body' when calling modifyTrustRuleset");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyTrustRuleset");
    }
    
    // create path and map variables
    String localVarPath = "/applicationcontroltrustrulesets/{acTrustRulesetID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "acTrustRulesetID" + "\\}", apiClient.escapeString(acTrustRulesetID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<TrustRuleset> localVarReturnType = new GenericType<TrustRuleset>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Set Trust Rule IDs in a Ruleset
   * Set only the specified trust rule IDs to be assigned to the trust ruleset.
   * @param acTrustRulesetID The ID number of the trust ruleset to modify. (required)
   * @param body The ID numbers of the trust rules to set. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return TrustRuleIDs
   * @throws ApiException if fails to make API call
   */
  public TrustRuleIDs setTrustRules(Long acTrustRulesetID, RuleLongIDs body, String apiVersion) throws ApiException {
    Object localVarPostBody = body;
    
    // verify the required parameter 'acTrustRulesetID' is set
    if (acTrustRulesetID == null) {
      throw new ApiException(400, "Missing the required parameter 'acTrustRulesetID' when calling setTrustRules");
    }
    
    // verify the required parameter 'body' is set
    if (body == null) {
      throw new ApiException(400, "Missing the required parameter 'body' when calling setTrustRules");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling setTrustRules");
    }
    
    // create path and map variables
    String localVarPath = "/applicationcontroltrustrulesets/{acTrustRulesetID}/rules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "acTrustRulesetID" + "\\}", apiClient.escapeString(acTrustRulesetID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<TrustRuleIDs> localVarReturnType = new GenericType<TrustRuleIDs>() {};
    return apiClient.invokeAPI(localVarPath, "PUT", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
