package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.ComputerExceptionRules;
import com.trendmicro.deepsecurity.model.PolicyExceptionRules;
import com.trendmicro.deepsecurity.model.SearchFilter;
import com.trendmicro.deepsecurity.model.USBDevice;
import com.trendmicro.deepsecurity.model.USBDevices;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class UsbStorageDevicesApi {
  private ApiClient apiClient;

  public UsbStorageDevicesApi() {
    this(Configuration.getDefaultApiClient());
  }

  public UsbStorageDevicesApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Create a USB Storage Device
   * Create a new USB storage device.
   * @param device The settings of the USB storage device to create. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return USBDevice
   * @throws ApiException if fails to make API call
   */
  public USBDevice createUSBDevice(USBDevice device, String apiVersion) throws ApiException {
    Object localVarPostBody = device;
    
    // verify the required parameter 'device' is set
    if (device == null) {
      throw new ApiException(400, "Missing the required parameter 'device' when calling createUSBDevice");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling createUSBDevice");
    }
    
    // create path and map variables
    String localVarPath = "/usbdevices".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<USBDevice> localVarReturnType = new GenericType<USBDevice>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Delete a USB Storage Device
   * Delete a USB storage device by ID.
   * @param deviceID The ID number of the USB storage device to delete. (required)
   * @param apiVersion The version of the api being called. (required)
   * @throws ApiException if fails to make API call
   */
  public void deleteUSBDevice(Long deviceID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'deviceID' is set
    if (deviceID == null) {
      throw new ApiException(400, "Missing the required parameter 'deviceID' when calling deleteUSBDevice");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling deleteUSBDevice");
    }
    
    // create path and map variables
    String localVarPath = "/usbdevices/{deviceID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "deviceID" + "\\}", apiClient.escapeString(deviceID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };


    apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, null);
  }
  /**
   * Describe a USB Storage Device
   * Describe a USB storage device by ID.
   * @param deviceID The ID number of the USB storage device to describe. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return USBDevice
   * @throws ApiException if fails to make API call
   */
  public USBDevice describeUSBDevice(Long deviceID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'deviceID' is set
    if (deviceID == null) {
      throw new ApiException(400, "Missing the required parameter 'deviceID' when calling describeUSBDevice");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeUSBDevice");
    }
    
    // create path and map variables
    String localVarPath = "/usbdevices/{deviceID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "deviceID" + "\\}", apiClient.escapeString(deviceID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<USBDevice> localVarReturnType = new GenericType<USBDevice>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Device Exception Rules
   * Lists device exception rules for this device assigned to computers.
   * @param deviceID The ID number of the USB storage device. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return ComputerExceptionRules
   * @throws ApiException if fails to make API call
   */
  public ComputerExceptionRules listComputerExceptionRules(Long deviceID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'deviceID' is set
    if (deviceID == null) {
      throw new ApiException(400, "Missing the required parameter 'deviceID' when calling listComputerExceptionRules");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listComputerExceptionRules");
    }
    
    // create path and map variables
    String localVarPath = "/usbdevices/{deviceID}/computerexceptionrules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "deviceID" + "\\}", apiClient.escapeString(deviceID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<ComputerExceptionRules> localVarReturnType = new GenericType<ComputerExceptionRules>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Device Exception Rules
   * Lists device exception rules for this device assigned to policies.
   * @param deviceID The ID number of the USB storage device. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return PolicyExceptionRules
   * @throws ApiException if fails to make API call
   */
  public PolicyExceptionRules listPolicyExceptionRules(Long deviceID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'deviceID' is set
    if (deviceID == null) {
      throw new ApiException(400, "Missing the required parameter 'deviceID' when calling listPolicyExceptionRules");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listPolicyExceptionRules");
    }
    
    // create path and map variables
    String localVarPath = "/usbdevices/{deviceID}/policyexceptionrules".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "deviceID" + "\\}", apiClient.escapeString(deviceID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<PolicyExceptionRules> localVarReturnType = new GenericType<PolicyExceptionRules>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List USB Storage Devices
   * Lists all USB storage devices.
   * @param apiVersion The version of the api being called. (required)
   * @return USBDevices
   * @throws ApiException if fails to make API call
   */
  public USBDevices listUSBDevices(String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listUSBDevices");
    }
    
    // create path and map variables
    String localVarPath = "/usbdevices".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<USBDevices> localVarReturnType = new GenericType<USBDevices>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Modify a USB Storage Device
   * Modify a USB storage device by ID. Any unset elements will be left unchanged.
   * @param deviceID The ID number of the USB storage device to modify. (required)
   * @param device The settings of the USB storage device to modify. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return USBDevice
   * @throws ApiException if fails to make API call
   */
  public USBDevice modifyUSBDevice(Long deviceID, USBDevice device, String apiVersion) throws ApiException {
    Object localVarPostBody = device;
    
    // verify the required parameter 'deviceID' is set
    if (deviceID == null) {
      throw new ApiException(400, "Missing the required parameter 'deviceID' when calling modifyUSBDevice");
    }
    
    // verify the required parameter 'device' is set
    if (device == null) {
      throw new ApiException(400, "Missing the required parameter 'device' when calling modifyUSBDevice");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyUSBDevice");
    }
    
    // create path and map variables
    String localVarPath = "/usbdevices/{deviceID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "deviceID" + "\\}", apiClient.escapeString(deviceID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<USBDevice> localVarReturnType = new GenericType<USBDevice>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Search USB Storage Devices
   * Search for USB storage devices using optional filters.
   * @param searchFilter A collection of options used to filter the search results. (optional)
   * @param apiVersion The version of the api being called. (required)
   * @return USBDevices
   * @throws ApiException if fails to make API call
   */
  public USBDevices searchUSBDevices(SearchFilter searchFilter, String apiVersion) throws ApiException {
    Object localVarPostBody = searchFilter;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling searchUSBDevices");
    }
    
    // create path and map variables
    String localVarPath = "/usbdevices/search".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<USBDevices> localVarReturnType = new GenericType<USBDevices>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
