package com.trendmicro.deepsecurity.api;

import com.trendmicro.deepsecurity.ApiException;
import com.trendmicro.deepsecurity.ApiClient;
import com.trendmicro.deepsecurity.Configuration;
import com.trendmicro.deepsecurity.Pair;

import javax.ws.rs.core.GenericType;

import com.trendmicro.deepsecurity.model.MigrationInformation;
import com.trendmicro.deepsecurity.model.WorkloadSecurityLink;
import com.trendmicro.deepsecurity.model.WorkloadSecurityLinks;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@javax.annotation.Generated(value = "io.swagger.codegen.languages.JavaClientCodegen", date = "2024-03-20T04:42:32.040Z")
public class WorkloadSecurityLinksApi {
  private ApiClient apiClient;

  public WorkloadSecurityLinksApi() {
    this(Configuration.getDefaultApiClient());
  }

  public WorkloadSecurityLinksApi(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  public ApiClient getApiClient() {
    return apiClient;
  }

  public void setApiClient(ApiClient apiClient) {
    this.apiClient = apiClient;
  }

  /**
   * Create a Workload Security Link
   * Can create only one Workload Security Link, delete it to create another one.
   * @param workloadSecurityLink The workload security link to create. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return WorkloadSecurityLink
   * @throws ApiException if fails to make API call
   */
  public WorkloadSecurityLink createWorkloadSecurityLink(WorkloadSecurityLink workloadSecurityLink, String apiVersion) throws ApiException {
    Object localVarPostBody = workloadSecurityLink;
    
    // verify the required parameter 'workloadSecurityLink' is set
    if (workloadSecurityLink == null) {
      throw new ApiException(400, "Missing the required parameter 'workloadSecurityLink' when calling createWorkloadSecurityLink");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling createWorkloadSecurityLink");
    }
    
    // create path and map variables
    String localVarPath = "/workloadsecuritylinks".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<WorkloadSecurityLink> localVarReturnType = new GenericType<WorkloadSecurityLink>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Delete a Workload Security Link
   * Delete a Workload Security Link by ID.
   * @param workloadSecurityLinkID The ID number of the workload security link to delete. (required)
   * @param apiVersion The version of the api being called. (required)
   * @throws ApiException if fails to make API call
   */
  public void deleteWorkloadSecurityLink(Long workloadSecurityLinkID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'workloadSecurityLinkID' is set
    if (workloadSecurityLinkID == null) {
      throw new ApiException(400, "Missing the required parameter 'workloadSecurityLinkID' when calling deleteWorkloadSecurityLink");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling deleteWorkloadSecurityLink");
    }
    
    // create path and map variables
    String localVarPath = "/workloadsecuritylinks/{workloadSecurityLinkID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "workloadSecurityLinkID" + "\\}", apiClient.escapeString(workloadSecurityLinkID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };


    apiClient.invokeAPI(localVarPath, "DELETE", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, null);
  }
  /**
   * Describe a Workload Security Link
   * Describe a Workload Security Link by ID.
   * @param workloadSecurityLinkID The ID number of the workload security link to describe. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return WorkloadSecurityLink
   * @throws ApiException if fails to make API call
   */
  public WorkloadSecurityLink describeWorkloadSecurityLinks(Long workloadSecurityLinkID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'workloadSecurityLinkID' is set
    if (workloadSecurityLinkID == null) {
      throw new ApiException(400, "Missing the required parameter 'workloadSecurityLinkID' when calling describeWorkloadSecurityLinks");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling describeWorkloadSecurityLinks");
    }
    
    // create path and map variables
    String localVarPath = "/workloadsecuritylinks/{workloadSecurityLinkID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "workloadSecurityLinkID" + "\\}", apiClient.escapeString(workloadSecurityLinkID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<WorkloadSecurityLink> localVarReturnType = new GenericType<WorkloadSecurityLink>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Get migration information through the Workload Security Link
   * Get migration information through the Workload Security Link.
   * @param workloadSecurityLinkID The ID number of the Workload Security Link. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return MigrationInformation
   * @throws ApiException if fails to make API call
   */
  public MigrationInformation getMigrationInformation(Long workloadSecurityLinkID, String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'workloadSecurityLinkID' is set
    if (workloadSecurityLinkID == null) {
      throw new ApiException(400, "Missing the required parameter 'workloadSecurityLinkID' when calling getMigrationInformation");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling getMigrationInformation");
    }
    
    // create path and map variables
    String localVarPath = "/workloadsecuritylinks/{workloadSecurityLinkID}/migrationinformation".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "workloadSecurityLinkID" + "\\}", apiClient.escapeString(workloadSecurityLinkID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<MigrationInformation> localVarReturnType = new GenericType<MigrationInformation>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * List Workload Security Links
   * List Workload Security Links.
   * @param apiVersion The version of the api being called. (required)
   * @return WorkloadSecurityLinks
   * @throws ApiException if fails to make API call
   */
  public WorkloadSecurityLinks listWorkloadSecurityLinks(String apiVersion) throws ApiException {
    Object localVarPostBody = null;
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling listWorkloadSecurityLinks");
    }
    
    // create path and map variables
    String localVarPath = "/workloadsecuritylinks".replaceAll("\\{format\\}","json");

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<WorkloadSecurityLinks> localVarReturnType = new GenericType<WorkloadSecurityLinks>() {};
    return apiClient.invokeAPI(localVarPath, "GET", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
  /**
   * Update a Workload Security Link
   * Update a Workload Security Link.
   * @param workloadSecurityLinkID The ID number of the workload security link. (required)
   * @param workloadSecurityLink The workload security link to create. (required)
   * @param apiVersion The version of the api being called. (required)
   * @return WorkloadSecurityLink
   * @throws ApiException if fails to make API call
   */
  public WorkloadSecurityLink modifyWorkloadSecurityLink(Long workloadSecurityLinkID, WorkloadSecurityLink workloadSecurityLink, String apiVersion) throws ApiException {
    Object localVarPostBody = workloadSecurityLink;
    
    // verify the required parameter 'workloadSecurityLinkID' is set
    if (workloadSecurityLinkID == null) {
      throw new ApiException(400, "Missing the required parameter 'workloadSecurityLinkID' when calling modifyWorkloadSecurityLink");
    }
    
    // verify the required parameter 'workloadSecurityLink' is set
    if (workloadSecurityLink == null) {
      throw new ApiException(400, "Missing the required parameter 'workloadSecurityLink' when calling modifyWorkloadSecurityLink");
    }
    
    // verify the required parameter 'apiVersion' is set
    if (apiVersion == null) {
      throw new ApiException(400, "Missing the required parameter 'apiVersion' when calling modifyWorkloadSecurityLink");
    }
    
    // create path and map variables
    String localVarPath = "/workloadsecuritylinks/{workloadSecurityLinkID}".replaceAll("\\{format\\}","json")
      .replaceAll("\\{" + "workloadSecurityLinkID" + "\\}", apiClient.escapeString(workloadSecurityLinkID.toString()));

    // query params
    List<Pair> localVarQueryParams = new ArrayList<Pair>();
    Map<String, String> localVarHeaderParams = new HashMap<String, String>();
    Map<String, Object> localVarFormParams = new HashMap<String, Object>();


    if (apiVersion != null)
      localVarHeaderParams.put("api-version", apiClient.parameterToString(apiVersion));

    
    final String[] localVarAccepts = {
      "application/json"
    };
    final String localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);

    final String[] localVarContentTypes = {
      "application/json"
    };
    final String localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

    String[] localVarAuthNames = new String[] { "DefaultAuthentication" };

    GenericType<WorkloadSecurityLink> localVarReturnType = new GenericType<WorkloadSecurityLink>() {};
    return apiClient.invokeAPI(localVarPath, "POST", localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
      }
}
